_positive = set(
    [
        "abba",
        "habilidade",
        "NO TRANSLATION",
        "absoluto",
        "absolvição",
        "absorvido",
        "abundante",
        "acadêmico",
        "Academia",
        "aceitável",
        "aceitação",
        "acessível",
        "elogio",
        "alojamento",
        "acompanhamento",
        "realizar",
        "realizado",
        "realização",
        "acordo",
        "prestação de contas",
        "responsável",
        "credenciado",
        "NO TRANSLATION",
        "preciso",
        "ás",
        "alcançar",
        "realização",
        "reconhecimento",
        "adquirir",
        "adquirindo",
        "acrobata",
        "açao",
        "real",
        "acuidade",
        "perspicácia",
        "adaptar",
        "adaptável",
        "endereços",
        "adepto",
        "NO TRANSLATION",
        "adjunto",
        "admirável",
        "almirante",
        "admiração",
        "admirar",
        "admirador",
        "admissível",
        "adorável",
        "adoração",
        "adorar",
        "avançar",
        "avançado",
        "avanço",
        "vantagem",
        "vantajoso",
        "advento",
        "aventura",
        "aventureiro",
        "aconselhável",
        "aconselhar",
        "conselheiro",
        "advocacia",
        "estético",
        "estética",
        "afável",
        "afeição",
        "afiliado",
        "afirmar",
        "afirmação",
        "afirmativo",
        "afirmativamente",
        "afluência",
        "afluente",
        "proporcionar",
        "NO TRANSLATION",
        "ágil",
        "agilidade",
        "aceita",
        "agradável",
        "acordado",
        "concordando",
        "acordo",
        "agricultura",
        "adiante",
        "ajuda",
        "auxiliando",
        "alabastro",
        "estado de alerta",
        "NO TRANSLATION",
        "vivo",
        "desculpe",
        "fidelidade",
        "allegro",
        "aliviar",
        "alívio",
        "aliado",
        "permitido",
        "fascínio",
        "atraente",
        "aliado",
        "todo-poderoso",
        "aloha",
        "Surpreendentemente",
        "embaixador",
        "ambição",
        "melhorar",
        "um homem",
        "acessível",
        "alterar",
        "corrigir",
        "amenidade",
        "amável",
        "amigável",
        "anistia",
        "NO TRANSLATION",
        "divertir",
        "divertido",
        "diversão",
        "divertido",
        "analista",
        "âncora",
        "ancoragem",
        "anjo",
        "angélico",
        "animar",
        "animado",
        "antibióticos",
        "antídoto",
        "antifúngico",
        "Antiguidade",
        "antisséptico",
        "aplomo",
        "apologético",
        "pedir desculpas",
        "desculpa",
        "apóstolo",
        "aplausos",
        "apreciação",
        "aprovação",
        "aprovação",
        "aprovar",
        "aprovando",
        "apto",
        "aptidão",
        "arqueologia",
        "ardente",
        "ardor",
        "aristocracia",
        "aristocrático",
        "armaduras",
        "aroma",
        "despertar",
        "matriz",
        "arte",
        "articular",
        "articulação",
        "artesão",
        "NO TRANSLATION",
        "artístico",
        "ascendência",
        "subida",
        "aspiração",
        "aspirar",
        "aspirando",
        "montagem",
        "concordância",
        "afirmando",
        "ativos",
        "ajudar",
        "assistência",
        "associado",
        "assuação",
        "garantia",
        "Assured",
        "NO TRANSLATION",
        "espanto",
        "astrólogo",
        "astronauta",
        "astrônomo",
        "astuto",
        "atleta",
        "Atlético",
        "átomo",
        "expiar",
        "expiação",
        "anexo",
        "atingível",
        "realização",
        "atendente",
        "atenção",
        "atenciosa",
        "atestar",
        "advogado",
        "atração",
        "atratividade",
        "aumentar",
        "agosto",
        "tia",
        "aura",
        "auspicioso",
        "autêntico",
        "autenticidade",
        "autor",
        "autoritativo",
        "autoridade",
        "autorização",
        "autorizado",
        "avatar",
        "prêmio",
        "ay",
        "Sim",
        "bebê",
        "bacharelado",
        "espinha dorsal",
        "equilibrar",
        "equilibrado",
        "balada",
        "balé",
        "cédula",
        "bálsamo",
        "banquete",
        "batismo",
        "batismal",
        "bardo",
        "barganha",
        "basquetebol",
        "bastião",
        "banho",
        "feixe",
        "radiante",
        "Embelezamento",
        "bonita",
        "embelezar",
        "beleza",
        "base rochosa",
        "Cerveja",
        "adequado",
        "befriend",
        "acreditando",
        "benfeitor",
        "benéfico",
        "beneficiar",
        "benevolência",
        "benigno",
        "atracar",
        "noiva",
        "melhoramento",
        "bebida",
        "bíblico",
        "bilíngüe",
        "nascimento",
        "aniversário",
        "sem culpa",
        "abençoe",
        "abençoado",
        "bênção",
        "bênçãos",
        "felicidade",
        "feliz",
        "sem sangue",
        "flor",
        "Flor",
        "escolta",
        "negrito",
        "ousadia",
        "reforço",
        "bonança",
        "NO TRANSLATION",
        "bônus",
        "bookish",
        "livraria",
        "benção",
        "generoso",
        "recompensa",
        "ramalhete",
        "cérebro",
        "bravura",
        "café da manhã",
        "nupcial",
        "noiva",
        "noivo",
        "dama de honra",
        "iluminar",
        "brilho",
        "brilhante",
        "brocado",
        "irmão",
        "fraternidade",
        "fraternal",
        "camarada",
        "construir",
        "construção",
        "buldogue",
        "a prova de balas",
        "bóia",
        "barramento",
        "mordomo",
        "amanteigado",
        "buxom",
        "zumbido",
        "táxi",
        "gabinete",
        "café",
        "calculadora",
        "bezerro",
        "calma",
        "canário",
        "sincero",
        "candidato",
        "cristalizado",
        "capitalista",
        "capitão",
        "cativar",
        "cativante",
        "carreira",
        "Cuidado",
        "cuidadosamente",
        "carícia",
        "zelador",
        "Carol",
        "cascata",
        "dinheiro",
        "categórico",
        "atender",
        "catártico",
        "catedral",
        "cauteloso",
        "com cautela",
        "célebre",
        "a comemorar",
        "celebração",
        "celestial",
        "Centro",
        "centurião",
        "cerebral",
        "cerimônia",
        "certeza",
        "presidente",
        "presidente",
        "campeão",
        "canto",
        "carregador",
        "caridosa",
        "caridade",
        "charme",
        "encantador",
        "castidade",
        "tagarelando",
        "lista de controle",
        "torcer",
        "alegre",
        "alegria",
        "torcendo",
        "NO TRANSLATION",
        "químico",
        "apreciar",
        "cereja",
        "chefe",
        "criança",
        "infância",
        "chilro",
        "formão",
        "cavalheirismo",
        "chocolate",
        "escolha",
        "coro",
        "coral",
        "coro",
        "escolhido",
        "sopa",
        "crônica",
        "chuckle",
        "Igreja",
        "cidra",
        "circuncisão",
        "cidadão",
        "Civil",
        "civilidade",
        "civilização",
        "civilizado",
        "clarividente",
        "aplaudir",
        "esclarecer",
        "clássico",
        "clássico",
        "clássicos",
        "classificar",
        "limpar \ limpo",
        "limpeza",
        "limpeza",
        "limpa",
        "limpar",
        "limpeza",
        "liberação",
        "clareza",
        "clerical",
        "esperto",
        "inteligência",
        "clímax",
        "proximidade",
        "fecho",
        "NO TRANSLATION",
        "palhaço",
        "aliança",
        "costa",
        "coexiste",
        "convincente",
        "cognitivo",
        "coerência",
        "coerente",
        "coeso",
        "coletivamente",
        "coronel",
        "colossal",
        "conforto",
        "comandante",
        "comandando",
        "comemorar",
        "comemoração",
        "comemorativo",
        "recomendar",
        "louvável",
        "comentarista",
        "comprometido",
        "comodoro",
        "comunidade",
        "comunicar",
        "comunicativo",
        "comunhão",
        "comunidade",
        "comutação",
        "comutar",
        "companheiro",
        "compaixão",
        "compassivo",
        "compatibilidade",
        "compatível",
        "atraente",
        "compensar",
        "compensatório",
        "competência",
        "competência",
        "competente",
        "complacência",
        "complemento",
        "complementar",
        "completamente",
        "completude",
        "completando",
        "conclusão",
        "conformidade",
        "compatível",
        "NO TRANSLATION",
        "composto",
        "compositor",
        "compostura",
        "compreender",
        "compreensivo",
        "camarada",
        "concêntrico",
        "conciliação",
        "concluindo",
        "concórdia",
        "concordância",
        "pêsames",
        "perdoar",
        "propício",
        "condutividade",
        "confederado",
        "confiança",
        "confiante",
        "confirmado",
        "conformidade",
        "agradável",
        "congratulatório",
        "congregação",
        "congruência",
        "conhecedor",
        "consciência",
        "conscienciosa",
        "consciência",
        "consagração",
        "conservação",
        "conservar",
        "considerável",
        "atencioso",
        "consistência",
        "console",
        "consoante",
        "constância",
        "constante",
        "constitucional",
        "construir",
        "consumar",
        "contato",
        "contemplação",
        "conteúdo",
        "continuar",
        "contorno",
        "contribuir",
        "contribuinte",
        "conveniência",
        "conveniente",
        "convento",
        "convenção",
        "familiarizado",
        "conversacional",
        "converter",
        "convencer",
        "legal",
        "frieza",
        "colaborar",
        "cooperando",
        "cooperação",
        "cooperativo",
        "testemunho",
        "coroação",
        "corporação",
        "corpóreo",
        "corretivo",
        "correspondência",
        "corroborar",
        "Cosmopolita",
        "acolhedor",
        "conselho",
        "conselho",
        "conselheiro",
        "contagem",
        "condessa",
        "coragem",
        "corajoso",
        "cortês",
        "cortesia",
        "namoro",
        "enseada",
        "pacto",
        "berço",
        "construir",
        "artesão",
        "creme",
        "crio",
        "criativo",
        "crédito",
        "credencial",
        "credibilidade",
        "credível",
        "crédito",
        "NO TRANSLATION",
        "creditado",
        "crescendo",
        "crítica",
        "coroando",
        "crucial",
        "cristal",
        "abraço",
        "culinária",
        "culminação",
        "cultivar",
        "cultivado",
        "cultivo",
        "cultura",
        "curável",
        "curiosidade",
        "ondulação",
        "almofada",
        "cliente",
        "fofa",
        "cortadores",
        "dame",
        "dança",
        "ousada",
        "querida",
        "correndo",
        "filha",
        "alvorecer",
        "acordo",
        "caro",
        "debate",
        "decência",
        "decente",
        "declaratório",
        "dedicação",
        "defender",
        "defendeu",
        "defensor",
        "defendendo",
        "defesa",
        "deferência",
        "definitivo",
        "grau",
        "deliciosa",
        "delegar",
        "deliberar",
        "delicioso",
        "deleite",
        "Deleitado",
        "delicioso",
        "libertação",
        "Entrega",
        "democracia",
        "demonstrável",
        "demonstrativo",
        "profundidade",
        "descritivo",
        "merecer",
        "mereceu",
        "designer",
        "desejável",
        "desejando",
        "desejoso",
        "destino",
        "detectar",
        "detecção",
        "determinação",
        "determinado",
        "desenvolve",
        "devocional",
        "devoto",
        "destreza",
        "diamante",
        "diário",
        "dicionário",
        "didático",
        "dietético",
        "digna",
        "dignidade",
        "diligência",
        "jantar",
        "diplomacia",
        "diplomático",
        "diretor",
        "descoberta",
        "NO TRANSLATION",
        "critério",
        "discricionária",
        "discussão",
        "desinfecção",
        "eliminado",
        "disseminar",
        "destilação",
        "distinção",
        "cantiga",
        "diversificado",
        "desvio",
        "divindade",
        "médico",
        "fazendeiro",
        "obstinado",
        "golfinho",
        "don",
        "doação",
        "sem dúvida",
        "pomba",
        "baixo",
        "dueto",
        "duque",
        "durabilidade",
        "durável",
        "obediente",
        "ansioso",
        "ânsia",
        "conde",
        "ganhar",
        "fervoroso",
        "fervorosamente",
        "fervor",
        "facilidade",
        "servidão",
        "NO TRANSLATION",
        "comer",
        "êxtase",
        "extático",
        "edificação",
        "educar",
        "educado",
        "educacional",
        "eficaz",
        "eficácia",
        "eficiência",
        "eficiente",
        "esforço",
        "ejaculação",
        "elaboração",
        "exaltado",
        "mais velho",
        "anciãos",
        "eleger",
        "elétrico",
        "eletricidade",
        "elegância",
        "elegante",
        "elevação",
        "elegíveis",
        "elite",
        "eloquência",
        "eloquente",
        "elucidar",
        "emancipação",
        "abraço",
        "emérito",
        "eminência",
        "eminente",
        "eminentemente",
        "NO TRANSLATION",
        "empatia",
        "capacitar",
        "emular, imitar",
        "habilitar",
        "habilitação",
        "encantar",
        "encantada",
        "encantador",
        "NO TRANSLATION",
        "encorajar",
        "encorajamento",
        "enciclopédia",
        "esforço",
        "dotar",
        "dotado",
        "doação",
        "resistência",
        "suportar",
        "energético",
        "acionado",
        "noivando",
        "realçar",
        "apreciar",
        "desfrutando",
        "ilumine",
        "iluminação",
        "animar",
        "enriquecer",
        "conjunto",
        "bandeira",
        "empreendedor",
        "entreter",
        "entretido",
        "divertido",
        "entretenimento",
        "entusiasmo",
        "entusiasta",
        "NO TRANSLATION",
        "efemérides",
        "épico",
        "epítome",
        "igualdade",
        "igualmente",
        "equilíbrio",
        "capital próprio",
        "incumbência",
        "erudito",
        "esprit",
        "essencial",
        "estabelecido",
        "estima",
        "estético",
        "ético",
        "ética",
        "evergreen",
        "eterno",
        "evidente",
        "evolução",
        "exaltar",
        "exaltação",
        "exaltado",
        "ultrapassarem",
        "excel",
        "excelência",
        "excelente",
        "troca",
        "excitável",
        "excitação",
        "excitar",
        "animado",
        "excitação",
        "emocionante",
        "exemplar",
        "isenção",
        "alegria",
        "exortar",
        "exortação",
        "existência",
        "exótico",
        "Espero",
        "expectativa",
        "expediente",
        "expedição",
        "com experiência",
        "especialista",
        "perícia",
        "explicar",
        "requintado",
        "exquisitamente",
        "ampliar",
        "extenso",
        "extra",
        "extraordinário",
        "extirpar",
        "exuberância",
        "facilitar",
        "fatos",
        "Faculdade",
        "NO TRANSLATION",
        "justo",
        "bastante",
        "fé",
        "fiel",
        "fama",
        "familiar",
        "familiaridade",
        "famoso",
        "famoso",
        "chique",
        "fanfarra",
        "fascinante",
        "fascinação",
        "elegante",
        "irrepreensível",
        "favorável",
        "favorito",
        "favoritismo",
        "destemido",
        "Parceria",
        "característica",
        "felicidade",
        "companheiro",
        "companheirismo",
        "fêmea",
        "fertil",
        "fervor",
        "festival",
        "festivo",
        "NO TRANSLATION",
        "fidelidade",
        "festa",
        "finalmente",
        "finery",
        "finesse",
        "bola fogo",
        "a prova de fogo",
        "firmeza",
        "NO TRANSLATION",
        "apropriado",
        "montagem",
        "lisonjeiro",
        "frota",
        "flexibilidade",
        "floral",
        "fluxo",
        "florido",
        "rubor",
        "vôo",
        "foco",
        "gosto",
        "Comida",
        "futebol",
        "paciência",
        "fore",
        "antepassados",
        "acima expostos",
        "capataz",
        "precursor",
        "prever",
        "previsto",
        "previsão",
        "forja",
        "perdoar",
        "perdoado",
        "perdoando",
        "formativo",
        "Fórmula",
        "NO TRANSLATION",
        "próximo",
        "fortalecer",
        "fortaleza",
        "fortaleza",
        "afortunado",
        "fortuna",
        "frente",
        "encontrado",
        "Fundação",
        "perfumado",
        "frank",
        "franqueza",
        "fraterno",
        "liberdade",
        "livremente",
        "amigos",
        "simpatia",
        "amigáveis",
        "amizade",
        "frisky",
        "frolic",
        "frugal",
        "frutuoso",
        "Preencha",
        "cumprimento",
        "cheio",
        "totalmente",
        "Diversão",
        "fundamental",
        "fusível",
        "fusão",
        "ganho",
        "ganhando",
        "galante",
        "galanteria",
        "abundância",
        "jardim",
        "granada",
        "guarnição",
        "gazette",
        "engrenagem",
        "gema",
        "geral",
        "generosidade",
        "generoso",
        "genial",
        "gênio",
        "gentil",
        "cavalheiro",
        "gentileza",
        "gentry",
        "genuíno",
        "gerânio",
        "presente",
        "dotado",
        "gigantesco",
        "rir",
        "viga",
        "dando",
        "feliz",
        "alegria",
        "alegria",
        "deslizar",
        "vislumbre",
        "brilhando",
        "glorificação",
        "glorificar",
        "glória",
        "lustro",
        "brilho",
        "brilhante",
        "Deus",
        "piedoso",
        "entrega de Deus",
        "ouro",
        "Boa",
        "bem",
        "bondade",
        "bens",
        "boa vontade",
        "linda",
        "gospel",
        "governo",
        "graça",
        "gracioso",
        "gracioso",
        "graciosamente",
        "graduação",
        "netos",
        "grandeza",
        "avó",
        "conceder",
        "concedido",
        "grato",
        "satisfazer",
        "gratidão",
        "maior",
        "grandeza",
        "verde",
        "cumprimento",
        "gregário",
        "sorrir",
        "grist",
        "areia",
        "trabalho de base",
        "crescer",
        "crescimento",
        "garantia",
        "guarda",
        "guardião",
        "tutela",
        "governamental",
        "orientação",
        "guia",
        "guia",
        "guru",
        "culhões",
        "ginasta",
        "habitat",
        "hale",
        "acessível",
        "alegremente",
        "felicidade",
        "feliz",
        "robusto",
        "harmoniosamente",
        "harmonia",
        "colheita",
        "refúgio",
        "progresso",
        "curar",
        "cura",
        "saudável",
        "saudável",
        "sincero",
        "lareira",
        "cordialmente",
        "celestial",
        "céus",
        "peso",
        "capacete",
        "ajudante",
        "útil",
        "ervas",
        "herói",
        "heróico",
        "heroics",
        "heroína",
        "heroísmo",
        "auge",
        "Hilário",
        "hilaridade",
        "contratar",
        "passatempo",
        "feriado",
        "santidade",
        "piedosos",
        "homenagem",
        "homologia",
        "honesto",
        "honestidade",
        "mel",
        "lua de mel",
        "honra",
        "honroso",
        "esperança",
        "esperançoso",
        "horizonte",
        "hospitalidade",
        "família",
        "serviço de limpeza",
        "abraço",
        "humano",
        "humanitário",
        "humanidade",
        "humilhado",
        "humildemente",
        "humildade",
        "humorista",
        "humorístico",
        "hurra",
        "pecuária",
        "silêncio",
        "cabana",
        "higiênico",
        "hino",
        "idealismo",
        "ídolo",
        "NO TRANSLATION",
        "iluminação",
        "ilustrar",
        "ilustre",
        "imaginativo",
        "imaculado",
        "imenso",
        "imergir",
        "imortal",
        "transmitir",
        "imparcial",
        "imparcialidade",
        "impecável",
        "impermeável",
        "importância",
        "importante",
        "impressionar",
        "impressão",
        "melhorar",
        "melhorado",
        "melhoria",
        "melhorando",
        "improvisar",
        "inalienável",
        "inauguração",
        "incisivo",
        "incluir",
        "incluído",
        "Incluindo",
        "inclusive",
        "aumentar",
        "indelével",
        "indenização",
        "independência",
        "indestrutível",
        "individualidade",
        "indomável",
        "inefável",
        "barato",
        "infalível",
        "infantil",
        "infinito",
        "infinidade",
        "influente",
        "em formação",
        "engenhoso",
        "herança",
        "inimitável",
        "inocência",
        "inocente",
        "inocentemente",
        "inócuo",
        "inovar",
        "inovação",
        "inquiridor",
        "inquérito",
        "inquisitivo",
        "inseparável",
        "insígnia",
        "inspetor",
        "inspiração",
        "inspirar",
        "inspirado",
        "instintivo",
        "instruir",
        "instrução",
        "instrutor",
        "instrumental",
        "garantir",
        "intacta",
        "integridade",
        "intelecto",
        "intelectual",
        "inteligência",
        "inteligente",
        "pretendido",
        "relações sexuais",
        "interesse",
        "interessado",
        "interessante",
        "interior",
        "interlocutório",
        "interlúdio",
        "íntimo",
        "entonação",
        "intrépido",
        "intuição",
        "intuitivo",
        "invariavelmente",
        "inventivo",
        "inventor",
        "investigar",
        "revigorar",
        "convite",
        "convite",
        "convidativo",
        "ferro",
        "irredutível",
        "irrefutável",
        "jackpot",
        "geléia",
        "NO TRANSLATION",
        "trabalho",
        "Junte-se",
        "ingressou",
        "palhaço",
        "brincadeira",
        "jornalista",
        "viagem",
        "jovial",
        "alegria",
        "alegre",
        "feliz",
        "jubiloso",
        "jubileu",
        "judicial",
        "judicioso",
        "saltar",
        "justiça",
        "justificável",
        "justificação",
        "lembrança",
        "ken",
        "keynote",
        "pedra angular",
        "tipo",
        "bondade",
        "parentes",
        "rei",
        "beijo",
        "gatinho",
        "habilidade",
        "cavaleiro",
        "sabendo",
        "conhecimento",
        "felicidades",
        "trabalho",
        "Cordeiro",
        "terra",
        "desembarcou",
        "laser",
        "louvável",
        "rir",
        "rindo",
        "riso",
        "lançamento",
        "laureado",
        "louro",
        "louros",
        "generoso",
        "legal",
        "conduzir",
        "líder",
        "liga",
        "aprender",
        "Aprendendo",
        "conferencista",
        "margem de manobra",
        "legal",
        "legalizado",
        "lendário",
        "legibilidade",
        "legível",
        "lazer",
        "vagamente",
        "lema",
        "indulgente",
        "lição",
        "com letras",
        "nível",
        "alavancagem",
        "libertar",
        "libertação",
        "liberdade",
        "biblioteca",
        "sangue vital",
        "farol",
        "gosto",
        "linguista",
        "leão",
        "ágil",
        "lógico",
        "longevidade",
        "senhoria",
        "adorável",
        "amor",
        "adorável",
        "NO TRANSLATION",
        "amante",
        "amoroso",
        "fiel",
        "fidelidade",
        "sorte",
        "por sorte",
        "gostoso",
        "brilho",
        "brilhante",
        "luxuriante",
        "luxuoso",
        "luxo",
        "lira",
        "lírico",
        "mágico",
        "magnético",
        "magnetismo",
        "magnetita",
        "magnificência",
        "magnífico",
        "donzela",
        "a Principal",
        "principal",
        "majestoso",
        "majestade",
        "principal",
        "maioria",
        "gerir",
        "gestão",
        "mandarim",
        "masculinidade",
        "manifestado",
        "viril",
        "maná",
        "educado",
        "maneiras",
        "fabricante",
        "marcha",
        "marcado",
        "comercializável",
        "marquês",
        "casamento",
        "medula",
        "casar",
        "marechal",
        "maravilha",
        "maravilhoso",
        "maravilhosamente",
        "masculino",
        "massagem",
        "mestre",
        "obra-prima",
        "domínio",
        "companheiro",
        "matrimônio",
        "matrona",
        "máximo",
        "prefeito",
        "Prado",
        "medido",
        "medalha",
        "mediar",
        "mediação",
        "mediador",
        "médico",
        "NO TRANSLATION",
        "Mediterrâneo",
        "medley",
        "lembrança",
        "memorável",
        "reparando",
        "menstruação",
        "mentor",
        "misericordioso",
        "misericórdia",
        "fundir",
        "mérito",
        "meritório",
        "alegria",
        "alegre",
        "metropolitano",
        "mettle",
        "microscopia",
        "obstetrícia",
        "poderoso",
        "Mime",
        "atento",
        "atenção plena",
        "ministério",
        "milagre",
        "milagroso",
        "alegria",
        "missionário",
        "modelo",
        "moderado",
        "moderador",
        "modesto",
        "modéstia",
        "impulso",
        "monetária",
        "dinheiro",
        "monge",
        "monumento",
        "moral",
        "moralidade",
        "moral",
        "argamassa",
        "maternidade",
        "motivo",
        "móvel",
        "motor",
        "muscular",
        "música",
        "musical",
        "mutável",
        "mútuo",
        "sesta",
        "naturalista",
        "navegável",
        "ordenadamente",
        "néctar",
        "agulha",
        "negociar",
        "negociador",
        "vizinho",
        "nervo",
        "aninhar",
        "nobreza",
        "nobre",
        "nobre",
        "nomeação",
        "normalidade",
        "notável",
        "notáveis",
        "NO TRANSLATION",
        "noção",
        "nutrição",
        "números",
        "enfermeira",
        "berçário",
        "nutrir",
        "nutritivo",
        "carvalho",
        "oásis",
        "juramento",
        "obediência",
        "objetivo",
        "obrigando",
        "atento",
        "obtido",
        "óbvio",
        "ocupante",
        "ocupação",
        "ocupar",
        "oferta",
        "oficial",
        "offset",
        "ramo",
        "onisciente",
        "abertura",
        "ópera",
        "oportuno",
        "oportunidade",
        "otimismo",
        "otimista",
        "opção",
        "opcional",
        "oráculo",
        "oração",
        "orquestra",
        "ordenado",
        "ordenadamente",
        "ordenação",
        "orgânico",
        "organização",
        "organizar",
        "organizado",
        "orgasmo",
        "originalidade",
        "ornamentado",
        "ornamentado",
        "resultado",
        "superado",
        "para fora",
        "muito feliz",
        "esmagadora",
        "propriedade",
        "pacífico",
        "almofada",
        "preenchimento",
        "paddle",
        "palatável",
        "paliativo",
        "panaceia",
        "panache",
        "NO TRANSLATION",
        "paprika",
        "Paragon",
        "primordial",
        "perdão",
        "parentesco",
        "parietal",
        "participar",
        "participação",
        "parceiro",
        "parceria",
        "paixão",
        "apaixonado",
        "passatempo",
        "pastor",
        "pastelaria",
        "pasto",
        "patente",
        "paciência",
        "paciente",
        "patriarcal",
        "patrono",
        "patrocínio",
        "pagamento",
        "Paz",
        "pacífico",
        "pacífico",
        "pavão",
        "peck",
        "peculiaridade",
        "pedigree",
        "inigualável",
        "penchante",
        "perceber",
        "perceptível",
        "perene",
        "perfeito",
        "perfeição",
        "artista",
        "perk",
        "permissão",
        "perpetuidade",
        "persistência",
        "persistente",
        "agradável",
        "pertinente",
        "farmacêutico",
        "filantropo",
        "filantropia",
        "filósofo",
        "Fénix",
        "fonético",
        "médico",
        "física",
        "fisiologia",
        "físico",
        "escolher",
        "piquenique",
        "pitoresco",
        "piedade",
        "comprimido",
        "travesseiro",
        "piloto",
        "pináculo",
        "pioneiro",
        "piedoso",
        "pith",
        "pivô",
        "plácido",
        "planejamento",
        "brincalhão",
        "Parque infantil",
        "casa de jogos",
        "agradável",
        "satisfeito",
        "agradável",
        "juramento",
        "plenário",
        "abundante",
        "plexo",
        "ameixa",
        "prumo",
        "pelúcia",
        "ply",
        "apontadamente",
        "polícia",
        "policial",
        "polonês",
        "polido",
        "educado",
        "polidez",
        "NO TRANSLATION",
        "piscina",
        "papa",
        "popularidade",
        "popularizado",
        "população",
        "portátil",
        "possuir",
        "potável",
        "potência",
        "poderoso",
        "poderosamente",
        "prática",
        "praticado",
        "prática",
        "elogio",
        "elogiado",
        "louvável",
        "orar",
        "precaução",
        "preceder",
        "precedência",
        "precioso",
        "preciso",
        "precisão",
        "predileção",
        "predominante",
        "preeminente",
        "preferem",
        "Premier",
        "instalações",
        "preparar",
        "preparado",
        "presciente",
        "presença",
        "presente",
        "apresentável",
        "conservante",
        "preservar",
        "Presidente",
        "prestígio",
        "presto",
        "bonita",
        "prevalecer",
        "prevenção",
        "impagável",
        "orgulho",
        "sacerdote",
        "sacerdócio",
        "sacerdotal",
        "primazia",
        "primário",
        "Prime",
        "primer",
        "Principe",
        "principesco",
        "Princesa",
        "diretor",
        "pristine",
        "privilegiado",
        "probidade",
        "procedimento",
        "procissão",
        "gerente",
        "procurar",
        "prodigioso",
        "prodígio",
        "produtor",
        "produzindo",
        "Produção",
        "produtivo",
        "produtividade",
        "profissão",
        "profissional",
        "professor",
        "proficiência",
        "proficiente",
        "profusa",
        "progresso",
        "progressão",
        "progressivo",
        "prolífico",
        "proeminência",
        "proeminente",
        "promessa",
        "promissor",
        "promoção",
        "suporte",
        "apropriado",
        "profeta",
        "profilático",
        "proposição",
        "perspectiva",
        "prosperar",
        "prosperidade",
        "próspero",
        "proteger",
        "protegendo",
        "protetor",
        "protetor",
        "orgulhoso",
        "provar",
        "proverbial",
        "providenciar",
        "fornecendo",
        "prudência",
        "Prudente",
        "salmo",
        "público",
        "puxar",
        "púlpito",
        "pontual",
        "pontualidade",
        "cachorro",
        "puramente",
        "purificação",
        "purificar",
        "purista",
        "pureza",
        "ronronar",
        "pitoresco",
        "qualificado",
        "qualificando",
        "busca",
        "questão",
        "rapidez",
        "quiescente",
        "quieto",
        "quinina",
        "resplandecer",
        "radiante",
        "irradiar",
        "rádio",
        "arrebatado",
        "êxtase",
        "racional",
        "leitor",
        "prontamente",
        "prontidão",
        "leitura",
        "reafirmar",
        "real",
        "razão",
        "resseguro",
        "tranquilizar",
        "desconto",
        "reformulação",
        "recebido",
        "recebendo",
        "NO TRANSLATION",
        "retribuir",
        "recuperação",
        "reclinar",
        "reconhecível",
        "recomendo",
        "reconciliação",
        "reconsideração",
        "reconstruir",
        "reconstrução",
        "gravador",
        "recuperar",
        "recuperação",
        "lazer",
        "recreativo",
        "retificar",
        "redenção",
        "reparação",
        "refinar",
        "refinamento",
        "reforma",
        "reforma",
        "reformador",
        "refrescante",
        "remodelar",
        "régio",
        "regente",
        "regularidade",
        "regular",
        "reabilitar",
        "reabilitação",
        "reembolsar",
        "reembolso",
        "reforço",
        "restabelecer",
        "alegrar",
        "alegria",
        "rejuvenescer",
        "rejuvenescido",
        "relaxamento",
        "relevante",
        "confiabilidade",
        "confiável",
        "dependência",
        "alívio",
        "aliviando",
        "refazer",
        "notável",
        "NO TRANSLATION",
        "remédio",
        "remissão",
        "remodelar",
        "renascimento",
        "renderizar",
        "renovação",
        "renovar",
        "renovação",
        "renome",
        "renomado",
        "reorganizar",
        "reparação",
        "reembolsar",
        "arrepender-se",
        "reabastecimento",
        "repleto",
        "repórter",
        "repouso",
        "representado",
        "reprodutiva",
        "respeitável",
        "resgatar",
        "reserva",
        "residente",
        "resiliente",
        "resistivo",
        "resolutamente",
        "Recursos",
        "respeito",
        "respeitabilidade",
        "respeitável",
        "respeitoso",
        "respeitando",
        "respeita",
        "descanso",
        "resplandecente",
        "responsável",
        "responsivo",
        "descansar",
        "repousante",
        "restituição",
        "restaurador",
        "restaurando",
        "restrição",
        "retomada",
        "retenção",
        "reunião",
        "revelar",
        "revela",
        "reverenciar",
        "reverência",
        "reverendo",
        "devaneio",
        "rever",
        "renascimento",
        "revolucionário",
        "recompensa",
        "ritmo",
        "rítmico",
        "fita",
        "riqueza",
        "cavaleiro",
        "justo",
        "legítimo",
        "com razão",
        "maduro",
        "amadurecer",
        "Aumentar",
        "rebitagem",
        "roadster",
        "robusto",
        "Rocha",
        "Cajado",
        "rodando",
        "romance",
        "romântico",
        "romantismo",
        "brincar",
        "enraizada",
        "rosado",
        "rota",
        "rotina",
        "realeza",
        "rubrica",
        "ruth",
        "seguro",
        "salvaguarda",
        "sábio",
        "santo",
        "santo",
        "salário",
        "saliente",
        "salutar",
        "saudação",
        "salvação",
        "salve",
        "samurai",
        "santificação",
        "santificar",
        "santuário",
        "otimista",
        "sanitário",
        "cetim",
        "satisfatoriamente",
        "satisfeito",
        "Salve ",
        "poupança",
        "saborear",
        "salgados",
        "experiente",
        "estudioso",
        "Bolsa de estudos",
        "científico",
        "cientista",
        "NO TRANSLATION",
        "Ponto",
        "escriba",
        "roteiro",
        "delicioso",
        "escultura",
        "mar",
        "foca",
        "temperado",
        "secretariado",
        "antiguidade",
        "sensacional",
        "sentido",
        "sensibilidade",
        "sensivel",
        "sensualidade",
        "sensual",
        "sentimental",
        "sentimentalismo",
        "sentinela",
        "serenidade",
        "sermão",
        "sérum",
        "settlor",
        "sexo",
        "forma",
        "bem torneado",
        "compartilhar",
        "abrigo",
        "pastor",
        "brilho",
        "brilhando",
        "compras",
        "ombro",
        "perspicaz",
        "seda",
        "simplificar",
        "sincero",
        "sinceridade",
        "cantar",
        "sozinho",
        "Senhor",
        "irmandade",
        "especializado",
        "hábil",
        "céu",
        "ardósia",
        "lustroso",
        "delgado",
        "fino",
        "sorrir",
        "sorridente",
        "ferido",
        "Suavidade",
        "snicker",
        "sobriedade",
        "sociável",
        "consolo",
        "soldado",
        "sólido",
        "solidez",
        "solução",
        "solvência",
        "sonar",
        "sonata",
        "soneto",
        "sonoro",
        "acalmar",
        "calmante",
        "NO TRANSLATION",
        "solidez",
        "sopa",
        "spa",
        "espaçoso",
        "spaniel",
        "brilhar",
        "especial",
        "NO TRANSLATION",
        "discurso",
        "veloz",
        "soletração",
        "especiaria",
        "espírito",
        "espíritos",
        "esplêndido",
        "esplendor",
        "patrocinador",
        "impecável",
        "cônjuge",
        "abeto",
        "estável",
        "staccato",
        "inoxidável",
        "garanhão",
        "stalwart",
        "energia",
        "parado",
        "Estrela",
        "luz das estrelas",
        "estrelado",
        "imponente",
        "declaração",
        "estátua",
        "status",
        "firme",
        "firme",
        "estelar",
        "mordomo",
        "quietude",
        "loja",
        "direto",
        "estratégico",
        "estrategista",
        "força",
        "fortalecer",
        "fortalecendo",
        "impressionante",
        "surpreendentemente",
        "fortemente",
        "estrutura",
        "viga",
        "estude",
        "robusto",
        "sublimação",
        "substância",
        "substantivo",
        "ter sucesso",
        "sucedendo",
        "sucesso",
        "bem sucedido",
        "sucinto",
        "suficiência",
        "açúcar",
        "adequado",
        "abafado",
        "dom",
        "ensolarado",
        "por do sol",
        "brilho do sol",
        "excelente",
        "super-humano",
        "superior",
        "superioridade",
        "Super homen",
        "Super estrela",
        "súplica",
        "suprimentos",
        "fornecem",
        "apoiado",
        "apoiador",
        "apoiando",
        "supremo",
        "supremamente",
        "garantia",
        "surpresa",
        "superando",
        "surpresa",
        "levantamento",
        "sobreviver",
        "jurar",
        "doce",
        "amada",
        "querida",
        "Doçura",
        "doces",
        "rápido",
        "nadar",
        "simbólico",
        "simétrico",
        "simetria",
        "simpático",
        "simpatia",
        "sinfonia",
        "sincronizar",
        "sinérgico",
        "sínodo",
        "tato",
        "conto",
        "talento",
        "talismã",
        "conversa",
        "bronzeada",
        "tarefa",
        "de bom gosto",
        "saboroso",
        "Ensinar",
        "professor",
        "tecnologia",
        "temperança",
        "temperado",
        "sustentável",
        "persistente",
        "tenacidade",
        "arrendamento",
        "inquilino",
        "concurso",
        "ternura",
        "grato",
        "Ação de graças",
        "teórico",
        "terapêutico",
        "terapêutica",
        "NO TRANSLATION",
        "puro sangue",
        "pensativo",
        "consideração",
        "economia",
        "emoção",
        "emocionante",
        "prosperando",
        "trono",
        "cócegas",
        "revestimento",
        "oportuno",
        "ouropel",
        "título",
        "torrada",
        "tolerante",
        "tolerância",
        "topo",
        "dureza",
        "torre",
        "alto",
        "tradicional",
        "tranquilo",
        "tranqüilidade",
        "transcendência",
        "transcendental",
        "viajando",
        "Tesouro",
        "árvore",
        "Tremendo",
        "tendência",
        "na moda",
        "afluente",
        "tributo",
        "trig",
        "triunfo",
        "triunfante",
        "troféu",
        "trégua",
        "VERDADE",
        "fiel",
        "verdade",
        "veracidade",
        "tutela",
        "tutor",
        "gêmeo",
        "cintilação",
        "em última análise",
        "árbitro",
        "unanimidade",
        "unânime",
        "modesto",
        "imparcial",
        "inquebrável",
        "inteiro",
        "sem restrições",
        "sublinhado",
        "compreensão",
        "subscrever",
        "indiviso",
        "imortal",
        "inequivocamente",
        "desdobrar",
        "unificação",
        "uniformemente",
        "não infectados",
        "único",
        "uníssono",
        "unitário",
        "Unidos",
        "unidade",
        "universidade",
        "ilimitado",
        "despretensioso",
        "inquestionável",
        "inquestionavelmente",
        "inquestionável",
        "incólume",
        "altruísta",
        "insuperável",
        "inabalável",
        "elevar",
        "ereto",
        "utilidade",
        "uj.",
        "usual",
        "utilidade",
        "utópico",
        "período de férias",
        "vacina",
        "valente",
        "NO TRANSLATION",
        "valioso",
        "vanguarda",
        "vencer",
        "veludo",
        "aveludado",
        "venerável",
        "veneração",
        "veracidade",
        "verdejante",
        "verificação",
        "verificado",
        "em verdade",
        "verdadeiro",
        "vernal",
        "verve",
        "veterano",
        "vigário",
        "vencedor",
        "vitorioso",
        "vitória",
        "vigilância",
        "Vigilância",
        "vigor",
        "vigoroso",
        "aldeão",
        "vindicado",
        "reivindicação",
        "virgem",
        "virgindade",
        "virtude",
        "virtuoso",
        "visão",
        "visionário",
        "Visita",
        "Visitante",
        "vital",
        "vitalidade",
        "vivaz",
        "vívido",
        "vocabulário",
        "voluntário",
        "voluptuoso",
        "atestar",
        "juramento",
        "salários",
        "garantia",
        "Guerreiro",
        "cão de guarda",
        "vigilante",
        "vigia",
        "à prova d'água",
        "riqueza",
        "resistente à intempérie",
        "bem vindo",
        "branco",
        "brancura",
        "saudável",
        "postigo",
        "generalizada",
        "de boa vontade",
        "disposição",
        "sorteiro",
        "vencedora",
        "ganhando",
        "ganhos",
        "sem fio",
        "wis",
        "sabedoria",
        "sensato",
        "sagacidade",
        "suportar",
        "inteligência",
        "espirituoso",
        "bruxo",
        "útero",
        "Maravilhoso",
        "maravilhosamente",
        "maravilhoso",
        "palavra",
        "trabalhando",
        "adoração",
        "que vale a pena",
        "digno",
        "wot",
        "escritor",
        "jovem",
        "mais jovem",
        "juventude",
        "zelo",
        "zeloso",
        "entusiasmo",
    ]
)

_negative = set(
    [
        "abandono",
        "abandonado",
        "abandono",
        "abdução",
        "aberrante",
        "aberração",
        "abominar",
        "abominável",
        "abjeta",
        "anormal",
        "abolir",
        "abolição",
        "abominável",
        "abominação",
        "abortar",
        "aborto",
        "abortivo",
        "abrasão",
        "revogar",
        "abscesso",
        "ausência",
        "ausente",
        "ausente",
        "absentismo",
        "absurdo",
        "absurdo",
        "Abuso",
        "abismal",
        "abismo",
        "acidente",
        "acidental",
        "maldito",
        "acusação",
        "acusativo",
        "acusado",
        "acusador",
        "acusando",
        "dor",
        "doendo",
        "ácido",
        "acionável",
        "adicionador",
        "vício",
        "adiposo",
        "julgar",
        "admoestação",
        "à deriva",
        "adulterado",
        "adultério",
        "adversário",
        "desfavoraveis",
        "adversidade",
        "afligir",
        "afligido",
        "aflição",
        "afronta",
        "receoso",
        "rescaldo",
        "Regresso",
        "agravado",
        "agravante",
        "agravamento",
        "agressão",
        "agressivo",
        "agressor",
        "horrorizado",
        "agitado",
        "agitação",
        "agonizante",
        "agonia",
        "encalhado",
        "todos",
        "doente",
        "sem rumo",
        "ar",
        "alarme",
        "alarmante",
        "alcoolismo",
        "estrangeiro",
        "alienar",
        "alienado",
        "alienação",
        "pensão alimentícia",
        "alegação",
        "alegar",
        "distante",
        "altercação",
        "ambíguo",
        "emboscada",
        "amnésia",
        "anfetaminas",
        "anaconda",
        "anal",
        "anarquismo",
        "anarquista",
        "anarquia",
        "anátema",
        "antigo",
        "raiva",
        "angina",
        "pesca",
        "Bravo",
        "angústia",
        "antipatia",
        "animus",
        "aniquilar",
        "aniquilado",
        "aniquilação",
        "incomodar",
        "aborrecimento",
        "irritante",
        "anular",
        "anulação",
        "anomalia",
        "anônimo",
        "antagonismo",
        "antagonista",
        "antagônico",
        "antraz",
        "anticristo",
        "antipatia",
        "antiquado",
        "anti-social",
        "antítese",
        "ansiedade",
        "ansioso",
        "apache",
        "apático",
        "apatia",
        "pulgão",
        "terrível",
        "apendicite",
        "apreensão",
        "apreensivo",
        "apropriação",
        "arcaico",
        "árduo",
        "argumentar",
        "argumento",
        "argumentativo",
        "árido",
        "armamentos",
        "acusação",
        "em atraso",
        "prender",
        "arrogância",
        "arrogante",
        "arsênico",
        "incêndio culposo",
        "artilharia",
        "cinza",
        "envergonhado",
        "cinzas",
        "bunda",
        "assalto",
        "assaltante",
        "assassino",
        "assassinar",
        "assassinato",
        "assalto",
        "Idiota",
        "desviado",
        "adstringente",
        "asilo",
        "ateísmo",
        "aterosclerose",
        "atroz",
        "atrocidade",
        "atrofia",
        "ataque",
        "atacante",
        "atenuada",
        "atenuação",
        "audácia",
        "austero",
        "austeridade",
        "autocrático",
        "autópsia",
        "avalanche",
        "avareza",
        "vingador",
        "aversa",
        "aversão",
        "evitar",
        "evasão",
        "horrível",
        "constrangimento",
        "errado",
        "balbuciar",
        "balbuciando",
        "babuíno",
        "para trás",
        "para trás",
        "remanso",
        "bactérias",
        "NO TRANSLATION",
        "mau",
        "texugo",
        "seriamente",
        "maldade",
        "oficial de justiça",
        "isca",
        "fardo",
        "balk",
        "NO TRANSLATION",
        "bandido",
        "bane",
        "bang",
        "Banger",
        "banir",
        "banido",
        "banimento",
        "falido",
        "falência",
        "alma penada",
        "barbear",
        "bárbaro",
        "bárbaro",
        "barbárie",
        "latido",
        "barrado",
        "estéril",
        "barricada",
        "barreira",
        "sem fundamento",
        "Desgraçado",
        "massa",
        "maltratado",
        "bateria",
        "batalha",
        "lutou",
        "campo de batalha",
        "bahdy",
        "baioneta",
        "O portador",
        "fera",
        "bestial",
        "espancamento",
        "acontecer",
        "implorar",
        "mendigo",
        "implorando",
        "gigante",
        "em dívida",
        "atrasado",
        "menosprezo",
        "beligerante",
        "cinto",
        "dobrador",
        "enlutado",
        "falecimento",
        "destituído",
        "berserk",
        "bestial",
        "trair",
        "traição",
        "tenha cuidado",
        "perplexo",
        "viés",
        "tendencioso",
        "brigas",
        "NO TRANSLATION",
        "intolerante",
        "intolerante",
        "bilis",
        "biópsia",
        "bétula",
        "local de nascimento",
        "cadela",
        "mordida",
        "amargamente",
        "amargura",
        "bizarro",
        "Preto",
        "blackjack",
        "chantagem",
        "escuridão",
        "culpa",
        "brando",
        "blasfemo",
        "blasfêmia",
        "explosão",
        "flagrante",
        "blather",
        "chama",
        "sombrio",
        "sangramento",
        "defeito",
        "ferrão",
        "destruído",
        "cego",
        "cego",
        "cegamente",
        "cegueira",
        "blister",
        "inchado",
        "blob",
        "bloqueio",
        "derramamento de sangue",
        "sanguinário",
        "sangrento",
        "borrão",
        "ventilador",
        "soprar",
        "blues",
        "blefe",
        "erro",
        "borrão",
        "borrado",
        "corar",
        "vangloriando-se",
        "pântano",
        "falso",
        "ferver",
        "boilerplate",
        "bombear",
        "bombardear",
        "bombardeamento",
        "bombardeou",
        "escravidão",
        "títulos",
        "vaia",
        "booby",
        "bebidas alcoólicas",
        "NO TRANSLATION",
        "tédio",
        "chato",
        "mutuário",
        "incomodar",
        "incomodando",
        "inferior",
        "limite",
        "ataque",
        "bovino",
        "Garoto",
        "boicote",
        "presumir",
        "conhaque",
        "bravata",
        "briga",
        "bronzeado",
        "violação",
        "demolir",
        "Breakneck",
        "NO TRANSLATION",
        "suborno",
        "suborno",
        "brigada",
        "enxofre",
        "cerda",
        "borda",
        "assar",
        "quebrou",
        "partido",
        "bordel",
        "ematoma",
        "peso",
        "brutal",
        "brutalidade",
        "bruto",
        "bufê",
        "erro",
        "NO TRANSLATION",
        "bulboso",
        "bully",
        "vagabundo",
        "vadio",
        "pesado",
        "burocracia",
        "burocrata",
        "assaltante",
        "roubo",
        "enterro",
        "enterrado",
        "burke",
        "queimado",
        "quebrado",
        "açougueiro",
        "butt",
        "zumbido",
        "cabala",
        "cacofonia",
        "cad",
        "cadáver",
        "cela",
        "calculando",
        "NO TRANSLATION",
        "chamadas",
        "campanha",
        "cancelar",
        "Câncer",
        "corroer",
        "canibal",
        "canibalismo",
        "NO TRANSLATION",
        "cativo",
        "cativeiro",
        "captor",
        "capturar",
        "carcaça",
        "carcinoma",
        "cardiomiopatia",
        "descuido",
        "caricatura",
        "cárie",
        "carnificina",
        "carnal",
        "carnívoro",
        "cartel",
        "caso",
        "caixão",
        "casta",
        "acidente",
        "catarata",
        "catástrofe",
        "cateter",
        "Cuidado",
        "ceder",
        "cemitério",
        "censurar",
        "censura",
        "cess",
        "cessação",
        "palha",
        "chafing",
        "desgosto",
        "desafio",
        "caos",
        "caótico",
        "charada",
        "exigível",
        "correr atrás",
        "castigo",
        "conversando",
        "barato",
        "enganação",
        "bolo de queijo",
        "chicana",
        "infantil",
        "frio",
        "clorofórmio",
        "sufocar",
        "cólera",
        "cortar",
        "tarefa",
        "crônica",
        "cigarro",
        "clamor",
        "choque",
        "chocando",
        "garra",
        "claustro",
        "nublado",
        "nebulosidade",
        "aglomerado",
        "desajeitado",
        "cocaína",
        "coagir",
        "coerção",
        "caixão",
        "frio",
        "friamente",
        "frieza",
        "cólica",
        "colapso",
        "colisão",
        "conluio",
        "coma",
        "comatosa",
        "combate",
        "combatente",
        "combativo",
        "compromisso",
        "comoção",
        "O comunismo",
        "comunista",
        "concorrência",
        "reclamar",
        "queixa",
        "complexo",
        "complexidade",
        "complicar",
        "complicado",
        "complicação",
        "composto",
        "compulsão",
        "obrigatório",
        "esconder",
        "escondido",
        "ocultação",
        "presunção",
        "pretensioso",
        "concussão",
        "condenar",
        "condenação",
        "condescendente",
        "condescendência",
        "confissão",
        "limitar",
        "confinado",
        "confinamento",
        "confiscar",
        "confisco",
        "conflagração",
        "conflito",
        "conflitante",
        "confundir",
        "confundido",
        "confundir",
        "confusão",
        "congestionamento",
        "conjuração",
        "conquista",
        "conspirador",
        "conspirar",
        "consternação",
        "Prisão de ventre",
        "restringindo",
        "constrangido",
        "limitação",
        "contágio",
        "contagioso",
        "contaminar",
        "contaminado",
        "contaminação",
        "desprezo",
        "desprezível",
        "desdenhoso",
        "contenciosa",
        "contrabando",
        "contratado",
        "contraditório",
        "contradição",
        "contraditório",
        "contrário",
        "contrastou",
        "contravenir",
        "contravenção",
        "controverso",
        "controvérsia",
        "condenar",
        "convicção",
        "cooperativa",
        "cópia de",
        "imitador",
        "legista",
        "corporal",
        "cadáver",
        "correção",
        "corrosão",
        "corrosivo",
        "corrupto",
        "corrompendo",
        "corrupção",
        "tosse",
        "conselheiro",
        "correndo",
        "cobiçar",
        "covarde",
        "covardia",
        "covardemente",
        "crabby",
        "crack",
        "rachado",
        "rachaduras",
        "cãibra",
        "apertado",
        "manivela",
        "irritadiço",
        "porcaria",
        "batida",
        "rastejar",
        "louco",
        "louco",
        "rangendo",
        "criatura",
        "rastejar",
        "crime",
        "Criminoso",
        "criminalidade",
        "encolher",
        "aleijado",
        "aleijado",
        "crise",
        "crisp",
        "crítico",
        "crítica",
        "criticar",
        "trapaceiro",
        "Cruz",
        "agachado",
        "crucipar",
        "crucificação",
        "bruto",
        "cruel",
        "cruelmente",
        "crueldade",
        "desmoronando",
        "crise",
        "cruzada",
        "esmagado",
        "esmagamento",
        "duro",
        "chorar",
        "chorando",
        "cripta",
        "corno",
        "cuco",
        "abate",
        "culpabilidade",
        "culpado",
        "culpado",
        "culto",
        "incômodo",
        "buzina",
        "cur",
        "maldição",
        "amaldiçoado",
        "maldição",
        "superficial",
        "cortador",
        "cutthroat",
        "corte",
        "cianeto",
        "ciclone",
        "cisto",
        "citomegalovírus",
        "dabbling",
        "daemon",
        "daft",
        "punhal",
        "danificar",
        "danos",
        "Droga",
        "condenação",
        "condenado",
        "amortecedor",
        "caspa",
        "dândi",
        "perigo",
        "perigoso",
        "escurecer",
        "escureceu",
        "Trevas",
        "tracejadas",
        "covarde",
        "atordoado",
        "desativar",
        "impasse",
        "mortal",
        "surdo",
        "morte",
        "debacle",
        "devassidão",
        "detritos",
        "dívida",
        "devedor",
        "decair",
        "decaído",
        "falecido",
        "engano",
        "enganosa",
        "enganar",
        "enganou",
        "enganando",
        "decepção",
        "enganosa",
        "declinação",
        "declínio",
        "declinante",
        "decomposição",
        "diminuir",
        "decremento",
        "decrépito",
        "Decry",
        "deduzir",
        "difamação",
        "difamatório",
        "padrão",
        "derrota",
        "derrotado",
        "defeito",
        "NO TRANSLATION",
        "defeituoso",
        "indefeso",
        "adiamento",
        "desafio",
        "desafiante",
        "deficiência",
        "déficit",
        "desinflar",
        "deflação",
        "deformar",
        "deformado",
        "deformidade",
        "defraudar",
        "extinto",
        "desafiar",
        "degeneração",
        "degenerar",
        "degradação",
        "degradar",
        "degradante",
        "demora",
        "atrasado",
        "deletério",
        "eliminação",
        "delinquência",
        "delinquente",
        "delirante",
        "delírio",
        "dilúvio",
        "ilusão",
        "delirante",
        "exigem",
        "exigente",
        "demente",
        "demência",
        "morte",
        "demolir",
        "demolição",
        "demônio",
        "demoníaco",
        "desmoralizado",
        "negação",
        "negado",
        "denunciar",
        "denúncia",
        "negar",
        "negando",
        "partiu",
        "saída",
        "dependência",
        "dependência",
        "deplorável",
        "deplorar",
        "deportar",
        "deportação",
        "depravado",
        "depravação",
        "depreciar",
        "depreciado",
        "depreciação",
        "deprimir",
        "depressivo",
        "deprimente",
        "depressão",
        "depressivo",
        "privação",
        "perturbado",
        "abandonado",
        "escárnio",
        "derrogação",
        "depreciativo",
        "profanação",
        "deserto",
        "deserta",
        "deserção",
        "desistir",
        "desolação",
        "desespero",
        "desesperando",
        "desesperado",
        "desprezível",
        "NO TRANSLATION",
        "despótico",
        "despotismo",
        "destituído",
        "destruído",
        "destruidor",
        "destruindo",
        "destruição",
        "destrutivo",
        "destacamento",
        "deter",
        "detido",
        "detenção",
        "deteriorar",
        "deteriorado",
        "deterioração",
        "detesto",
        "detonar",
        "prejudicar",
        "detrimento",
        "prejudicial",
        "detritos",
        "devastar",
        "devastador",
        "devastação",
        "diabo",
        "diabólico",
        "tortuoso",
        "devolução",
        "devorar",
        "diabólico",
        "diagnóstico",
        "diatribe",
        "ditador",
        "ditatorial",
        "ditadura",
        "NO TRANSLATION",
        "dificuldades",
        "dificuldade",
        "digress",
        "dilapidado",
        "diluir",
        "diminuir",
        "diminuído",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "sujeira",
        "sujo",
        "incapacidade",
        "desativar",
        "Desativado",
        "descontente",
        "discordar",
        "discordando",
        "desacordo",
        "desautorizado",
        "decepcionar",
        "desapontado",
        "desapontante",
        "desapontamento",
        "desaprovação",
        "desaprovar",
        "reprovado",
        "desaprovação",
        "desastre",
        "desastroso",
        "não acredite",
        "descarta",
        "descarga",
        "disciplina",
        "renunciar",
        "descoloração",
        "descolorido",
        "desconforto",
        "desconectar",
        "desconectado",
        "desconexão",
        "descontentamento",
        "descontinuar",
        "descontinuidade",
        "discórdia",
        "desencorajar",
        "desânimo",
        "desacreditar",
        "discriminar",
        "discriminando",
        "discriminação",
        "desdém",
        "doença",
        "doente",
        "desencarnado",
        "desengajamento",
        "desfigurado",
        "desgraça",
        "NO TRANSLATION",
        "vergonhoso",
        "desapontado",
        "desgosto",
        "repugnante",
        "Desanimado",
        "Desanimador",
        "desonesto",
        "desonestidade",
        "desonra",
        "desilusão",
        "desinformação",
        "falso",
        "desintegrar",
        "desintegração",
        "desinteressado",
        "não gosta",
        "não gostei",
        "deslocado",
        "lúgubre",
        "desânimo",
        "desmembramento",
        "demissão",
        "desobediência",
        "desobediente",
        "desobedecer",
        "desordem",
        "desordenado",
        "desorganizado",
        "desacreditar",
        "desprezando",
        "disparidade",
        "desapaixonado",
        "dissipar",
        "dispersão",
        "deslocar",
        "desagradado",
        "desagrado",
        "disposição",
        "despossuído",
        "disputa",
        "desqualificação",
        "desqualificado",
        "desqualificar",
        "desprezo",
        "desconsiderado",
        "infeliz",
        "desrespeito",
        "desrespeitoso",
        "interrupção",
        "insatisfação",
        "dissensão",
        "dissidente",
        "desserviço",
        "dissidente",
        "dissolução",
        "dissonância",
        "aversão",
        "desagradável",
        "distorcido",
        "distorção",
        "distrair",
        "distraído",
        "distraindo",
        "Distração",
        "perturbado",
        "angústia",
        "angustiado",
        "angustiante",
        "desconfiança",
        "perturbação",
        "perturbado",
        "desuso",
        "em desuso",
        "divergente",
        "despojado",
        "desinvestimento",
        "divórcio",
        "tontura",
        "tonto",
        "ancorado",
        "NO TRANSLATION",
        "Doldrums",
        "dole",
        "NO TRANSLATION",
        "dominante",
        "dominação",
        "asno",
        "doodle",
        "doom",
        "condenado",
        "Apocalipse",
        "dúvida",
        "duvidoso",
        "duvidando",
        "douche",
        "severo",
        "queda",
        "monótono",
        "drenagem",
        "recua",
        "temerar",
        "terrível",
        "terrivelmente",
        "aborrecido",
        "bebendo",
        "drivel",
        "drone",
        "caindo",
        "seca",
        "afogar",
        "sonolência",
        "trabalho pesado",
        "bêbado",
        "embriaguez",
        "duvidoso",
        "maçante",
        "burro",
        "manequim",
        "lixões",
        "dun",
        "masmorra",
        "enganar",
        "duplicidade",
        "coação",
        "poeira",
        "anão",
        "morrendo",
        "disenteria",
        "tremor de terra",
        "espionagem",
        "decreto",
        "efeminado",
        "egoísta",
        "egregious",
        "ejetar",
        "ejeção",
        "eliminação",
        "esquivo",
        "emaciado",
        "NO TRANSLATION",
        "embaraçar",
        "embaraçoso",
        "embaraço",
        "desfalco",
        "embolia",
        "envolvido",
        "emergência",
        "enclave",
        "invasão",
        "gravidez",
        "pôr em perigo",
        "ameaçadas de extinção",
        "endêmico",
        "inimigo",
        "execução",
        "enigmático",
        "inimizade",
        "escravizar",
        "escravizado",
        "escravização",
        "enredado",
        "emaranhamento",
        "entranhas",
        "invejoso",
        "epidemia",
        "epilepsia",
        "erradicar",
        "erradicação",
        "apagar",
        "erosão",
        "errar",
        "errante",
        "errático",
        "errata",
        "errôneo",
        "erro",
        "erupção",
        "erupção",
        "escalar",
        "evite",
        "espionagem",
        "alienado",
        "eutanásia",
        "evacuar",
        "evacuação",
        "evadir",
        "evasão",
        "despejar",
        "despejo",
        "mal",
        "exacerbar",
        "exacerbação",
        "exigente",
        "exagerar",
        "exagerado",
        "exame",
        "exasperação",
        "escavação",
        "excesso",
        "impostos especiais de consumo",
        "excluído",
        "excluindo",
        "exclusão",
        "excremento",
        "excruciante",
        "com licença",
        "execução",
        "carrasco",
        "escape",
        "Exausta",
        "exaustão",
        "NO TRANSLATION",
        "exílio",
        "exorcismo",
        "expatriado",
        "expulsar",
        "despesa",
        "despesas",
        "expirar",
        "expirado",
        "expletivo",
        "explodir",
        "explosão",
        "explosivo",
        "exposto",
        "expropriação",
        "expulsão",
        "exterminar",
        "extermínio",
        "extinto",
        "extinguir",
        "extrajudicial",
        "extremidade",
        "fabricar",
        "fabricação",
        "desvaneça",
        "fezes",
        "falhando",
        "falha",
        "desmaie",
        "Sem fé",
        "falso",
        "cair",
        "falaz",
        "falácia",
        "falível",
        "queda",
        "pousio",
        "falsidade",
        "falsamente",
        "falsificação",
        "falsificar",
        "falsidade",
        "vacilar",
        "fome",
        "fanático",
        "farsa",
        "farcical",
        "jejum",
        "gordo",
        "fatal",
        "fatalidade",
        "destino",
        "fadiga",
        "cansado",
        "gordinho",
        "culpa",
        "defeituoso",
        "fawn",
        "medo",
        "com medo",
        "com medo",
        "temendo",
        "febril",
        "fecal",
        "fezes",
        "taxa",
        "fraco",
        "fingido",
        "caiu",
        "criminoso",
        "crime",
        "fermentar",
        "feroz",
        "ferocidade",
        "feudo",
        "feudal",
        "feudalismo",
        "febril",
        "fiasco",
        "fib",
        "inconstante",
        "fictício",
        "demônio",
        "feroz",
        "luta",
        "combate",
        "filibuster",
        "sujeira",
        "sujo",
        "armas de fogo",
        "encaixa",
        "flácido",
        "flácido",
        "marcando",
        "flagrante",
        "Floco",
        "aba",
        "flatulência",
        "flaunt",
        "falha",
        "pulga",
        "NO TRANSLATION",
        "velo",
        "carnudo",
        "flinch",
        "flog",
        "flop",
        "linguado",
        "gripe",
        "flutuação",
        "inimigo",
        "frustrado",
        "loucura",
        "idiota",
        "Insensato",
        "loucura",
        "forragem",
        "incursão",
        "proibido",
        "proibindo",
        "força",
        "forçado",
        "forçosamente",
        "pressentimento",
        "encerrar",
        "renunciar",
        "estrangeiro",
        "estrangeiro",
        "prevenido",
        "perder",
        "perdeu",
        "confisco",
        "falsificação",
        "esqueço",
        "esquecido",
        "desamparado",
        "sem forma",
        "fornicação",
        "abandone",
        "abandonado",
        "falta",
        "fratura",
        "frágil",
        "fragilidade",
        "frenético",
        "fraude",
        "fraudulento",
        "cheio",
        "briga",
        "desgastado",
        "freakish",
        "congelando",
        "frenético",
        "frenético",
        "frenesi",
        "transtorno",
        "susto",
        "amedrontar",
        "assustado",
        "espantoso",
        "frígido",
        "frívolo",
        "congelamento",
        "espuma",
        "franzir a testa",
        "franzindo a testa",
        "infrutífero",
        "frustrar",
        "frustrado",
        "frustração",
        "lorota",
        "fugitivo",
        "fumble",
        "fumo",
        "fumando",
        "fungo",
        "funk",
        "furioso",
        "furor",
        "fúria",
        "discutir",
        "espalhafatoso",
        "inútil",
        "futilidade",
        "gaby",
        "mordaça",
        "galo",
        "forca",
        "jogar",
        "jogador",
        "jogos de azar",
        "gangue",
        "prisão",
        "gap",
        "lixo",
        "garish",
        "guarnição, enfeite, adorno",
        "corte",
        "ofegante",
        "NO TRANSLATION",
        "magro",
        "gent",
        "geriátrico",
        "horrível",
        "gueto",
        "espectral",
        "gibberish",
        "glacial",
        "brilho",
        "deslumbrante",
        "glib",
        "melancolia",
        "sombrio",
        "glum",
        "excesso",
        "gula",
        "gnomo",
        "goblin",
        "sem deus",
        "gonorréia",
        "goo",
        "gore",
        "desfiladeiro",
        "gorila",
        "sangrento",
        "fofoca",
        "gouge",
        "gota",
        "governo",
        "agarrar",
        "agarrando",
        "grato",
        "Grato",
        "grade",
        "grave",
        "ganância",
        "ávido",
        "Grenade",
        "tristeza",
        "queixa",
        "sofrer",
        "doloroso",
        "sombrio",
        "sujeira",
        "sujo",
        "esmerilhamento",
        "horrível",
        "grizzly",
        "gemido",
        "NO TRANSLATION",
        "Bruto",
        "grotesco",
        "aterrado",
        "sem fundamento",
        "rosnar",
        "rosnando",
        "rancor",
        "de má vontade",
        "horrível",
        "rude",
        "resmungar",
        "mal humorado",
        "guerrilha",
        "astúcia",
        "guilhotina",
        "culpa",
        "culpado",
        "disfarce",
        "gaivota",
        "crédulo",
        "arma de fogo",
        "jorrar",
        "Guzzling",
        "cigano",
        "bruxa",
        "abatido",
        "peludo",
        "a meio caminho",
        "alucinação",
        "cabeçada",
        "parando",
        "dificultar",
        "isquiotibigo",
        "handicap",
        "suspensão",
        "carrasco",
        "molestar",
        "prenúncio",
        "endurecido",
        "dureza",
        "dificuldade",
        "prostituta",
        "prejuízo",
        "prejudicial",
        "angustiante",
        "harry",
        "aspereza",
        "jogo da velha",
        "haxixe",
        "apressado",
        "ódio",
        "odioso",
        "odiando",
        "ódio",
        "altivo",
        "assombro",
        "assombrada",
        "havoc",
        "perigo",
        "perigoso",
        "neblina",
        "dor de cabeça",
        "inebriante",
        "audição",
        "boatos",
        "carro fúnebre",
        "mágoa",
        "azia",
        "sem coração",
        "pagão",
        "fortemente",
        "salto",
        "aumentar",
        "hediondo",
        "inferno",
        "infernal",
        "desamparado",
        "desamparo",
        "hemorragia",
        "hemorróidas",
        "heresia",
        "herege",
        "hermafrodita",
        "heroína",
        "herpes",
        "herpesvírus",
        "hesitação",
        "escondido",
        "horrível",
        "dificultando",
        "obstáculo",
        "hippie",
        "silvo",
        "silvo",
        "acertar",
        "até agora",
        "colméia",
        "rouco",
        "hoary",
        "engano",
        "vagabundo",
        "porco",
        "oco",
        "holocausto",
        "sem casa",
        "com saudades de casa",
        "homicida",
        "homicídio",
        "homossexualidade",
        "capuz",
        "viciado",
        "hoot",
        "sem esperança",
        "desesperança",
        "horda",
        "horrível",
        "horrivelmente",
        "horrível",
        "horrível",
        "horrorizado",
        "horrível",
        "Horror",
        "horrores",
        "refém",
        "hostil",
        "hostilidades",
        "hostilidade",
        "uivo",
        "huff",
        "humbug",
        "humilhar",
        "humilhante",
        "humilhação",
        "Hunch",
        "com fome",
        "caçador",
        "Caçando",
        "furacão",
        "apressado",
        "ferido",
        "doloroso",
        "machucando",
        "Hustler",
        "hidra",
        "hidrocefalia",
        "hype",
        "hipérbole",
        "hipocrisia",
        "hipócrita",
        "hipócrita",
        "histeria",
        "histérico",
        "idiotice",
        "idiota",
        "idiota",
        "usuário",
        "idolatria",
        "ignorância",
        "ignorante",
        "ignorar",
        "eu vou",
        "ilegal",
        "ilegalidade",
        "ilegível",
        "ilegítimo",
        "ilícito",
        "analfabetos",
        "doença",
        "ilógico",
        "ilusão",
        "imitado",
        "imitação",
        "imaturo",
        "imaturidade",
        "imoral",
        "imoralidade",
        "prejudicar",
        "prejuízo",
        "intransitável",
        "impaciência",
        "impaciente",
        "julgar",
        "impeachment",
        "impedir",
        "imperfeição",
        "imperfeitamente",
        "personificar",
        "representação",
        "implacável",
        "implicar",
        "indelicado",
        "imposição",
        "impossível",
        "impotência",
        "impotente",
        "Impound",
        "impraticável",
        "aprisionar",
        "preso",
        "prisão",
        "impropriedade",
        "imprudente",
        "impuro",
        "impureza",
        "imputação",
        "incapacidade",
        "inacessível",
        "impreciso",
        "inação",
        "inatividade",
        "NO TRANSLATION",
        "inadequado",
        "inadmissível",
        "inano",
        "inaplicável",
        "inapropriado",
        "falta de atenção",
        "inaudível",
        "incalculável",
        "incapacidade",
        "encarceramento",
        "em caso",
        "incendiário",
        "incenso",
        "incessante",
        "incesto",
        "incestuoso",
        "incineração",
        "incitar",
        "inclemente",
        "incoerente",
        "incompatível",
        "incompetência",
        "incompetente",
        "incompletude",
        "incompreensível",
        "incongruente",
        "inconsequente",
        "inconsiderado",
        "inconsistência",
        "inconveniente",
        "incorreta",
        "incrédulo",
        "incriminação",
        "incubus",
        "incorrer",
        "incurável",
        "incursão",
        "indecente",
        "indecisão",
        "indeciso",
        "indefensável",
        "indenizar",
        "escritura",
        "indeterminado",
        "acusação",
        "acusação",
        "indiferença",
        "indigente",
        "indignado",
        "indignação",
        "indistinto",
        "doutrinação",
        "indolente",
        "ineficaz",
        "ineficaz",
        "ineficiência",
        "ineficiente",
        "inepto",
        "inépcia",
        "desigualdade",
        "desigual",
        "inerte",
        "indesculpável",
        "NO TRANSLATION",
        "inexperiente",
        "inexplicável",
        "infame",
        "infâmia",
        "infanticídio",
        "infantil",
        "infarto",
        "infectar",
        "infecção",
        "infeccioso",
        "inferior",
        "inferioridade",
        "inferno",
        "infertilidade",
        "infestação",
        "infiel",
        "infidelidade",
        "enfermos",
        "enfermidade",
        "inflamação",
        "inflado",
        "inflação",
        "infligir",
        "inflicção",
        "gripe",
        "informante",
        "infração",
        "raramente",
        "violação",
        "inibir",
        "inóspito",
        "desumano",
        "desumanidade",
        "inimigo",
        "iniqüidade",
        "injunção",
        "ferir",
        "lesionado",
        "prejudicial",
        "prejuízo",
        "injustiça",
        "preso",
        "inoperante",
        "insano",
        "insanidade",
        "inseguro",
        "insegurança",
        "insidioso",
        "insignificância",
        "insignificante",
        "insípido",
        "insolente",
        "insolvência",
        "insolvente",
        "instabilidade",
        "instigar",
        "instigação",
        "insuficiência",
        "insuficiente",
        "insuficientemente",
        "insulto",
        "insultando",
        "insurgente",
        "intransponível",
        "insurreição",
        "inter",
        "interdição",
        "interferência",
        "enterro",
        "interromper",
        "interrompido",
        "intestado",
        "intimidar",
        "intimidação",
        "intolerável",
        "intolerância",
        "intolerante",
        "intoxicado",
        "intratável",
        "intriga",
        "intruso",
        "intrusão",
        "intrusivo",
        "invadir",
        "invasor",
        "invalidar",
        "invalidação",
        "invalidez",
        "invasão",
        "involuntário",
        "involução",
        "irado",
        "NO TRANSLATION",
        "ferros",
        "irracional",
        "irracionalidade",
        "irreconciliável",
        "irregular",
        "irregularidade",
        "irrelevante",
        "irreparável",
        "irresponsável",
        "irreverente",
        "irrevogável",
        "irritabilidade",
        "irritável",
        "irritante",
        "irritação",
        "isolado",
        "isolamento",
        "jabber",
        "cadeia",
        "jargão",
        "chateante",
        "icterícia",
        "com ciumes",
        "ciúmes",
        "comprometer",
        "perigo",
        "John",
        "gracejo",
        "NO TRANSLATION",
        "jumble",
        "lixo",
        "junta",
        "juvenil",
        "kern",
        "pontapé",
        "sequestro",
        "matar",
        "matando",
        "pipa",
        "soletrar",
        "anotado",
        "trabalhou",
        "trabalhoso",
        "labirinto",
        "falta",
        "em falta",
        "sem brilho",
        "carregado",
        "atraso",
        "atrasado",
        "covil",
        "lamento",
        "deslizamento de terra",
        "lânguido",
        "languidar",
        "languidecendo",
        "lapso",
        "roubo",
        "chicote",
        "atrasado",
        "atraso",
        "latente",
        "latrinas",
        "risível",
        "lava",
        "ilegalidade",
        "ação judicial",
        "advogado",
        "laxista",
        "laxante",
        "preguiçoso",
        "vazamento",
        "vazamento",
        "vazando",
        "sair",
        "sanguessuga",
        "sanguessuga",
        "NO TRANSLATION",
        "limão",
        "lepra",
        "lésbicas",
        "diminuir",
        "menor",
        "letal",
        "letargia",
        "leucemia",
        "imposição",
        "sensual",
        "ligação",
        "mentiroso",
        "difamação",
        "lamber",
        "mentira",
        "sem vida",
        "limitado",
        "coxear",
        "pelagem",
        "licor",
        "sem apelo",
        "litigante",
        "litigar",
        "litígio",
        "litigioso",
        "lixo",
        "lívido",
        "pão",
        "loafer",
        "NO TRANSLATION",
        "odeio",
        "repugnância",
        "repugnante",
        "lobista",
        "NO TRANSLATION",
        "gafanhoto",
        "alto",
        "solidão",
        "solitário",
        "solitário",
        "loo",
        "tear",
        "loon",
        "loony",
        "saque",
        "perder",
        "perdendo",
        "perda",
        "perdido",
        "intensidade",
        "salão",
        "piolho",
        "mais baixo",
        "abaixando",
        "menor",
        "Planícies",
        "humilde",
        "ridículo",
        "pesando",
        "nódulo",
        "grumoso",
        "loucura",
        "lunático",
        "lurch",
        "atrair",
        "lúgubre",
        "espreitar",
        "à espreita",
        "exuberante",
        "luxúria",
        "lustful",
        "deitado",
        "linchar",
        "mace",
        "louco",
        "louco",
        "louco",
        "loucura",
        "máfia",
        "larva",
        "improvisado",
        "doença",
        "Mal-estar",
        "malária",
        "malévolo",
        "prevaricação",
        "malformação",
        "malícia",
        "malicioso",
        "maligno",
        "malignidade",
        "maligno",
        "negligência",
        "mandamus",
        "NO TRANSLATION",
        "mangle",
        "mania",
        "maníaco",
        "maníaco",
        "manipular",
        "manipulação",
        "homicídio culposo",
        "estrume",
        "mar",
        "margem",
        "marrom",
        "martingale",
        "mártir",
        "martírio",
        "masoquismo",
        "massacre",
        "materialismo",
        "materialista",
        "Meandros",
        "sem significado",
        "sarampo",
        "intrometer",
        "medíocre",
        "mediocridade",
        "melancólico",
        "melancólico",
        "melee",
        "melodrama",
        "fusão",
        "ameaça",
        "ameaçador",
        "Menial",
        "mercenário",
        "implacável",
        "bagunça",
        "bagunçado",
        "metástase",
        "metanol",
        "mofo",
        "milícia",
        "mimetismo",
        "minimizar",
        "mínimo",
        "minoria",
        "NO TRANSLATION",
        "mau comportamento",
        "aborto espontâneo",
        "travessura",
        "pernicioso",
        "equívoco",
        "má conduta",
        "miserável",
        "miseravelmente",
        "miséria",
        "infortúnio",
        "equivocada",
        "acidente",
        "má interpretação",
        "enganar",
        "enganosa",
        "má gestão",
        "incompatibilidade",
        "nome incorreto",
        "misplace",
        "mal colocado",
        "deturpar",
        "deturpação",
        "mal representado",
        "ausência de",
        "distorção",
        "erro",
        "confundido",
        "amante",
        "NO TRANSLATION",
        "mal interpretado",
        "mal entendido",
        "mau uso",
        "ácaro",
        "mafia",
        "zombaria",
        "zombando",
        "molestation",
        "monocromático",
        "monopolista",
        "monção",
        "monstro",
        "monstruosidade",
        "temperamental",
        "discutível",
        "mórbido",
        "morbidade",
        "necrotério",
        "moribundo",
        "Idiota",
        "imbecil",
        "bocado",
        "mortal",
        "mortalidade",
        "mortificação",
        "mortuária",
        "mosquito",
        "chorar",
        "triste",
        "luto",
        "muck",
        "lama",
        "confusão",
        "confuso",
        "turvar",
        "muff",
        "mula",
        "mãe",
        "resmungar",
        "caxumba",
        "assassinato",
        "assassino",
        "assassino",
        "escuro",
        "NO TRANSLATION",
        "mofado",
        "mutante",
        "mutilado",
        "mutilação",
        "motim",
        "NO TRANSLATION",
        "focinho",
        "miopia",
        "nab",
        "nadir",
        "NO TRANSLATION",
        "ingênuo",
        "sem nome",
        "fralda",
        "narcótico",
        "desagradável",
        "danadinho",
        "náusea",
        "náuseas",
        "NO TRANSLATION",
        "indispensável",
        "carente",
        "nefasto",
        "negação",
        "negativo",
        "negligência",
        "negligenciado",
        "negligenciando",
        "negligência",
        "negligente",
        "NO TRANSLATION",
        "negro",
        "nepotismo",
        "nervoso",
        "inferno",
        "urtiga",
        "neuralgia",
        "neurose",
        "neurótico",
        "nicotina",
        "negro",
        "pesadelo",
        "niilismo",
        "barulho",
        "barulhento",
        "NO TRANSLATION",
        "Absurdo",
        "sem sentido",
        "noose",
        "nada",
        "nocivo",
        "incômodo",
        "NO TRANSLATION",
        "anular",
        "entorpecido",
        "entorpecimento",
        "NO TRANSLATION",
        "oaf",
        "obeso",
        "obesidade",
        "obi",
        "obit",
        "obituário",
        "objeção",
        "censurável",
        "obrigar",
        "Devedor",
        "obliterar",
        "obliterado",
        "obliteração",
        "esquecimento",
        "obnóxio",
        "obsceno",
        "obscenidade",
        "obscuridade",
        "obstáculo",
        "obstinado",
        "obstruir",
        "obstrução",
        "obstrutivo",
        "obtuso",
        "oculto",
        "estranheza",
        "odioso",
        "odor",
        "ofender",
        "ofendido",
        "ofensor",
        "ofensa",
        "ofensiva",
        "de improviso",
        "offing",
        "ogro",
        "olfativo",
        "oligarquia",
        "presságio",
        "sinistro",
        "omitir",
        "oneroso",
        "ônus",
        "escorrer",
        "opaco",
        "ópera",
        "opiáceo",
        "opinativo",
        "ópio",
        "oponente",
        "opor",
        "opôs-se",
        "oposição",
        "oprimir",
        "opressão",
        "opressivo",
        "opressor",
        "orc",
        "provação",
        "artilharia",
        "órfão",
        "ostensivamente",
        "expulsar",
        "exilado",
        "clamor",
        "dependência",
        "estranho",
        "bandido",
        "ultraje",
        "ovação",
        "arrogante",
        "sobrecarregar",
        "nublado",
        "exagerar",
        "overdose",
        "em atraso",
        "superestimado",
        "transbordar",
        "coberto de vegetação",
        "sobrecarga",
        "pago em excesso",
        "superação",
        "dominando",
        "muito caro",
        "supervisão",
        "derrubar",
        "reviravolta",
        "oprimir",
        "sobrecarregado",
        "devido",
        "oxidação",
        "dor",
        "dolorido",
        "doloroso",
        "dolorosamente",
        "dores",
        "paralisia",
        "pandemia",
        "NO TRANSLATION",
        "pânico",
        "paralisia",
        "paralisado",
        "paranóia",
        "parasita",
        "NO TRANSLATION",
        "papagaio",
        "parcimonioso",
        "partidário",
        "NO TRANSLATION",
        "passiva",
        "passividade",
        "patch",
        "patético",
        "paternalista",
        "NO TRANSLATION",
        "escassez",
        "pobre",
        "penhor",
        "retorno",
        "Forma de pagamento",
        "peculiaridades",
        "pedestre",
        "penal",
        "pena",
        "penetração",
        "penitenciária",
        "perdição",
        "perigo",
        "perigosa",
        "perecer",
        "perecível",
        "pereceu",
        "perecendo",
        "perjúrio",
        "pernicioso",
        "autor",
        "perpetuação",
        "perplexo",
        "perplexidade",
        "perseguir",
        "perseguição",
        "perturbação",
        "tosse convulsa",
        "perverso",
        "perversão",
        "perverter",
        "pervertido",
        "pessimismo",
        "pessimista",
        "praga",
        "peste",
        "animal",
        "mesquinho",
        "fantasma",
        "fleuma",
        "falso",
        "piquete",
        "piquete",
        "salmoura",
        "porco",
        "Pombo",
        "pilhas",
        "pilhagem",
        "cafetão",
        "espinha",
        "pinho",
        "pinhão",
        "pique",
        "pirataria",
        "pirata",
        "pistola",
        "armadilha",
        "plágio",
        "praga",
        "demandante",
        "chapeado",
        "jogador",
        "pedido",
        "situação difícil",
        "perseguindo",
        "prumo",
        "pilhagem",
        "mergulho",
        "pneumonia",
        "caça furtiva",
        "sem sentido",
        "Poção",
        "envenenado",
        "envenenamento",
        "venenoso",
        "cutucar",
        "polêmica",
        "poliomielite",
        "poluir",
        "poluição",
        "poligamia",
        "pompa",
        "pomposo",
        "pesado",
        "mal",
        "pop",
        "porco-espinho",
        "pornô",
        "porno",
        "pornográfico",
        "pornografia",
        "pose",
        "possuía",
        "posse",
        "póstumo",
        "adiamento",
        "libra",
        "pobreza",
        "impotente",
        "pegadinha",
        "precário",
        "precinto",
        "predatório",
        "dilema",
        "gravidez",
        "preconceito",
        "preconceituoso",
        "prejudicial",
        "premeditado",
        "pressão",
        "presunçoso",
        "faz de conta",
        "fingiu",
        "fingindo",
        "pretensão",
        "pretensões",
        "preventivo",
        "presa",
        "prick",
        "espinhoso",
        "prisão",
        "prisioneiro",
        "privy",
        "problema",
        "procrastinar",
        "Procrastinação",
        "profano",
        "profanidade",
        "profusão",
        "Entrada",
        "proibição",
        "prolongar",
        "promíscuo",
        "propaganda",
        "processar",
        "processo",
        "prostituta",
        "prostituição",
        "provocação",
        "provocando",
        "alavanca",
        "curioso",
        "psicose",
        "publicista",
        "inchado",
        "soco",
        "pungente",
        "punir",
        "punido",
        "punir",
        "punição",
        "punitivo",
        "purgatório",
        "purga",
        "pus",
        "Quack",
        "atoleiro",
        "Codorna",
        "dilema",
        "discussão",
        "anular",
        "calam",
        "questionável",
        "mercúrio",
        "Sair",
        "tremor",
        "tremendo",
        "questionário",
        "chute",
        "raivoso",
        "raiva",
        "prateleira",
        "raquete",
        "radiação",
        "radioativo",
        "radônio",
        "raiva",
        "furioso",
        "trapos",
        "ataque",
        "trilho",
        "RAM",
        "divagar",
        "rampage",
        "rançoso",
        "resgate",
        "estupro",
        "raptores",
        "patife",
        "erupção cutânea",
        "rato",
        "Avaliação",
        "estridente",
        "voraz",
        "delirante",
        "reacionário",
        "traseira",
        "rebelde",
        "repreensão",
        "refutar",
        "recalcitrante",
        "recessão",
        "reincidência",
        "imprudente",
        "imprudência",
        "redundante",
        "refluxo",
        "refratário",
        "recusa",
        "recusar",
        "recusou",
        "regredir",
        "regressão",
        "arrepender",
        "lamentável",
        "lamentou",
        "lamentando",
        "regulamentar",
        "rédea",
        "rejeitar",
        "rejeitado",
        "rejeição",
        "rejeita",
        "recaída",
        "rebaixamento",
        "renunciar",
        "relutante",
        "prisão preventiva",
        "remédio",
        "negligente",
        "remorso",
        "remoção",
        "remover",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "renegado",
        "renúncia",
        "renúncia",
        "NO TRANSLATION",
        "repelente",
        "repelindo",
        "reprimir",
        "repressão",
        "reprimenda",
        "reimprimir",
        "represália",
        "censura",
        "república",
        "repúdio",
        "repulsão",
        "rescindir",
        "rescisão",
        "ressentir",
        "ressentido",
        "ressentimento",
        "demitir-se",
        "renúncia",
        "resignado",
        "resistir",
        "resistência",
        "resistente",
        "resistindo",
        "restringir",
        "restringir",
        "restrição",
        "restritivo",
        "retaliar",
        "retaliação",
        "retaliação",
        "retardar",
        "retardo",
        "reticente",
        "retorta",
        "retrair",
        "retração",
        "retração",
        "retribuição",
        "retrógrado",
        "vingança",
        "reversão",
        "revogação",
        "revogar",
        "revolta",
        "revoltante",
        "revólver",
        "repulsa",
        "reumatismo",
        "raquítico",
        "riscado",
        "ridículo",
        "ridículo",
        "abundante",
        "rifle",
        "rift",
        "rígido",
        "rigidez",
        "rigor",
        "rigoroso",
        "campainha",
        "tumulto",
        "desenfreado",
        "risco",
        "arriscado",
        "rivalidade",
        "roubar",
        "ladrão",
        "roubo",
        "Vampiro",
        "torre",
        "podridão",
        "apodrecendo",
        "rugosidade",
        "NO TRANSLATION",
        "linha",
        "turbulento",
        "lixo",
        "destroços, Pedregulho",
        "rua",
        "ruffle",
        "áspero",
        "ruína",
        "arruinado",
        "ruinoso",
        "boato",
        "fugir",
        "ruptura",
        "NO TRANSLATION",
        "ferrugem",
        "oxidado",
        "cruel",
        "NO TRANSLATION",
        "sabotar",
        "sacrifícios",
        "Infelizmente",
        "tristeza",
        "sag",
        "seiva",
        "sarcasmo",
        "sarcoma",
        "sardônico",
        "satânico",
        "saturado",
        "selvagem",
        "selvageria",
        "costela",
        "andaime",
        "bisturi",
        "escamosa",
        "escândalo",
        "escandaloso",
        "escasso",
        "bode expiatório",
        "cicatriz",
        "escasso",
        "mal",
        "escassez",
        "susto",
        "scavenger",
        "esquema",
        "cisma",
        "esquizofrenia",
        "ciática",
        "zombar",
        "repreender",
        "repreensão",
        "escaldante",
        "desprezo",
        "escorpião",
        "escocês",
        "canalha",
        "flagelo",
        "revoltando",
        "Scrapie",
        "grito",
        "gritando",
        "screech",
        "parafusado",
        "scrimmage",
        "esfregar",
        "escrutinar",
        "escrutínio",
        "escumalha",
        "sear",
        "secessão",
        "isolado",
        "NO TRANSLATION",
        "secreção",
        "secreto",
        "sectário",
        "sedição",
        "seduzir",
        "sedução",
        "segregar",
        "segregado",
        "aproveitar",
        "egoísta",
        "egoísmo",
        "senil",
        "sem sentido",
        "frase",
        "separatista",
        "sepsis",
        "séptico",
        "sequestro",
        "sereno",
        "serpente",
        "servo",
        "servir",
        "servil",
        "servidão",
        "revés",
        "cortar",
        "esgoto",
        "sistema de esgoto",
        "gasto",
        "barraca",
        "manilha",
        "sombrio",
        "tremendo",
        "instável",
        "farsa, falso",
        "confusão",
        "vergonha",
        "vergonhoso",
        "desavergonhado",
        "Xangai",
        "Tubarão",
        "quebra",
        "quebrado",
        "galpão",
        "Concha",
        "arquivado",
        "naufrágio",
        "merda",
        "arrepio",
        "choque",
        "de má qualidade",
        "atirar",
        "tiroteio",
        "furto",
        "escassez",
        "lacuna",
        "tiro",
        "empurrão",
        "vistoso",
        "gritar",
        "estridente",
        "encolher",
        "encolhido",
        "estremecer",
        "evite",
        "doente",
        "devastador",
        "doentio",
        "doença",
        "boba",
        "NO TRANSLATION",
        "pecaminoso",
        "sinistro",
        "pecador",
        "pecando",
        "sirene",
        "mariquinhas",
        "céptico",
        "esboçado",
        "distorcido",
        "skid",
        "pular",
        "escaramuça",
        "folga",
        "escória",
        "slam",
        "calúnia",
        "calunioso",
        "tapa",
        "matança",
        "matadouro",
        "abate",
        "escravo",
        "escravidão",
        "Arrasar",
        "assassino",
        "granizo",
        "viscoso",
        "slink",
        "escorregar",
        "NO TRANSLATION",
        "descuidado",
        "preguiça",
        "desleixo",
        "slough",
        "lentidão",
        "lodo",
        "lama",
        "lerdo",
        "favela",
        "queda",
        "insulto",
        "lama",
        "puta",
        "sly",
        "smack",
        "pequeno",
        "esmagar",
        "esmagado",
        "dando certo",
        "cheiro",
        "cheirando",
        "sorrir",
        "desbaratar",
        "fumante",
        "sufocar",
        "mancha",
        "presunçoso",
        "contrabandear",
        "contrabandista",
        "contrabando",
        "cair",
        "snag",
        "inconvenientes",
        "serpente",
        "laço",
        "rosnar",
        "rosnando",
        "esgueirar-se",
        "furtivamente",
        "zombar",
        "espirrar",
        "esconderijo",
        "esnobe",
        "absorver",
        "NO TRANSLATION",
        "socialista",
        "solo",
        "sujado",
        "somático",
        "sombrio",
        "fuligem",
        "feitiçaria",
        "sórdido",
        "dorido",
        "sorrateiramente",
        "dor",
        "tristeza",
        "triste",
        "NO TRANSLATION",
        "Desumano",
        "alma gêmea",
        "azedar",
        "palmada",
        "espasmo",
        "cuspe",
        "lança",
        "speck",
        "espectro",
        "espectral",
        "especulação",
        "gasto",
        "solteirona",
        "apesar de",
        "rancoroso",
        "lasca",
        "Dividido",
        "dividindo",
        "estragar",
        "Spoiler",
        "falou",
        "esponja",
        "assustador",
        "entorse",
        "spree",
        "sprite",
        "espúrio",
        "tempestade",
        "ocupante",
        "exprimir",
        "squelch",
        "torcer",
        "facada",
        "assombroso",
        "estagnado",
        "mancha",
        "obsoleto",
        "tenda",
        "distanciamento",
        "parado",
        "encarando",
        "rígido",
        "de sobressalto",
        "fome",
        "morrendo de fome",
        "morrendo de fome",
        "estacionário",
        "stave",
        "roubar",
        "roubando",
        "furtivo",
        "estereótipo",
        "estereotipado",
        "estéril",
        "esterilidade",
        "popa",
        "rígido",
        "rigidez",
        "sufocar",
        "sufocado",
        "estigma",
        "nascido morto",
        "picada",
        "picada",
        "mesquinho",
        "fedor",
        "fedorento",
        "período",
        "estoques",
        "roubado",
        "pedra",
        "apedrejado",
        "fezes",
        "paralisação",
        "tempestade",
        "tormentoso",
        "tenso",
        "dificuldades",
        "encalhado",
        "desconhecido",
        "estrangular",
        "disperso",
        "estresse",
        "conflito",
        "greve",
        "faixa",
        "listra",
        "despojado",
        "acidente vascular encefálico",
        "luta",
        "strut",
        "abafado",
        "tropeçar",
        "atordoado",
        "atrofiado",
        "estúpido",
        "estupidez",
        "estupor",
        "chiqueiro",
        "subjugar",
        "sujeito",
        "sujeito",
        "sujeição",
        "subjugação",
        "subordinar",
        "intimação",
        "subsidência",
        "subvenção",
        "subsistir",
        "subtrair",
        "subversão",
        "subversivo",
        "subverter",
        "sucumbir",
        "chupar",
        "otário",
        "processar",
        "Sofra",
        "sofredor",
        "sofrimento",
        "sufocante",
        "asfixia",
        "suicida",
        "suicídio",
        "mal-humorado",
        "Convocação",
        "afundado",
        "superficial",
        "supérfluo",
        "supersticioso",
        "suprimir",
        "supressão",
        "sobretaxa",
        "grosseiro",
        "entrega",
        "rendição",
        "suscetível",
        "suspeito",
        "suspensão",
        "suspeita",
        "suspeito",
        "cotonete",
        "pântano",
        "pantanoso",
        "suástica",
        "inchaço",
        "gole",
        "suínos",
        "inchado",
        "sintoma",
        "síncope",
        "tabu",
        "mancha",
        "NO TRANSLATION",
        "emaranhado",
        "atraso",
        "tardia",
        "tarifa",
        "manchar",
        "tarry",
        "insípido",
        "provocação",
        "imposto",
        "provocação",
        "provocando",
        "tedioso",
        "NO TRANSLATION",
        "tempestade",
        "tentação",
        "habitação",
        "terminal",
        "terminação",
        "térmitas",
        "terrivel",
        "terror",
        "terrorismo",
        "terrorista",
        "aterrorizar",
        "tétano",
        "amarra",
        "roubo",
        "teísmo",
        "teocrático",
        "ladrao",
        "com sede",
        "Espinho",
        "espinhoso",
        "irrefletido",
        "thrash",
        "ameaça",
        "ameaçar",
        "ameaçador",
        "Thresh",
        "pulsar",
        "acelerador",
        "bandido",
        "batida",
        "trovão",
        "thwart",
        "tiff",
        "tímido",
        "timidez",
        "bêbado",
        "tirada",
        "cansado",
        "cansaço",
        "cansativo",
        "tit",
        "sapo",
        "tabaco",
        "banheiro",
        "toils",
        "tolerar",
        "dor de dente",
        "tormento",
        "rasgado",
        "torpedo",
        "tórrido",
        "delito",
        "tortuoso",
        "tortura",
        "tocou",
        "melindroso",
        "resistente",
        "tóxico",
        "toxina",
        "tragédia",
        "trágico",
        "traidor",
        "vagabundo",
        "transe",
        "transgressão",
        "armadilhas",
        "armadilhas",
        "Lixo",
        "inútil",
        "traumático",
        "NO TRANSLATION",
        "travessura",
        "traiçoeiro",
        "traição",
        "traição",
        "tremendo",
        "tremor",
        "trepidação",
        "transgressão",
        "tribulação",
        "tribunal",
        "truque",
        "enganar",
        "bagatela",
        "tropeçar",
        "troll",
        "problemático",
        "trombeta",
        "cair",
        "tumor",
        "tumor",
        "tumulto",
        "tumultuado",
        "turbulência",
        "turbulento",
        "turbulência",
        "contração muscular",
        "tufão",
        "tirânico",
        "tirania",
        "tirano",
        "feiúra",
        "feio",
        "úlcera",
        "ulterior",
        "ultimato",
        "incapaz",
        "inaceitável",
        "inexplicável",
        "desaprovado",
        "desapegado",
        "inalcançável",
        "pouco atraente",
        "não autorizado",
        "inevitável",
        "inconsciente",
        "insuportável",
        "incredulidade",
        "inacreditável",
        "nascituros",
        "estranho",
        "despreocupado",
        "incerto",
        "imutável",
        "imundo",
        "desconfortável",
        "desconsiderável",
        "inconsciente",
        "inconstitucional",
        "incontrolável",
        "descontrolado",
        "indeciso",
        "minado",
        "mal pago",
        "subdimensionado",
        "indesejável",
        "indesejável",
        "desfazer",
        "inquietação",
        "desconfortável",
        "sem instrução",
        "desempregado",
        "desigual",
        "desigual",
        "inexplicável",
        "Injusto",
        "injustiça",
        "infiel",
        "desfavorável",
        "inacabado",
        "implacável",
        "infeliz",
        "hostil",
        "não cumprido",
        "sem mobília",
        "ímpio",
        "ingrato",
        "infelicidade",
        "infeliz",
        "pouco saudável",
        "impiedade",
        "sem importância",
        "Não impressionado",
        "não melhorado",
        "desinformado",
        "não iniciados",
        "sem inspiração",
        "ininteligível",
        "sem querer",
        "desinteressado",
        "desinteressante",
        "injusto",
        "injustificável",
        "injustificado",
        "desagradável",
        "desconhecido",
        "ilegal",
        "sem licença",
        "azarado",
        "ingovernável",
        "não natural",
        "não oficial",
        "não remunerado",
        "desagradável",
        "impopular",
        "imprevisível",
        "despreparado",
        "improdutivo",
        "não lucrativo",
        "desprotegido",
        "inédito",
        "não confiável",
        "não correspondido",
        "indisciplinado",
        "inseguro",
        "insatisfatório",
        "insatisfeito",
        "desagradável",
        "sem escrúpulos",
        "inesgotável",
        "desagradável",
        "pouco sofisticado",
        "indizível",
        "instável",
        "mal sucedido",
        "inadequado",
        "desconhecido",
        "não suportado",
        "insustentável",
        "antipático",
        "indomado",
        "insustentável",
        "impensável",
        "desordenado",
        "intempestivo",
        "sem título",
        "incontável",
        "desagradável",
        "não treinado",
        "falso",
        "não confiável",
        "injustificado",
        "não lavado",
        "indesejável",
        "indisposto",
        "falta de vontade",
        "imprudente",
        "inconsciente",
        "indigno",
        "inflexível",
        "transtorno",
        "revolta",
        "tumulto",
        "chateado",
        "Ouriço",
        "urgente",
        "sem utilidade",
        "usurpar",
        "usurpado",
        "usura",
        "vaga",
        "vazio",
        "vago",
        "imprecisão",
        "em vão",
        "vampiro",
        "desapareceu",
        "vaidade",
        "varicela",
        "varizes",
        "vegetativo",
        "veemente",
        "vendeta",
        "vingança",
        "vingativo",
        "veneno",
        "venenoso",
        "verbosidade",
        "Beira",
        "vermes",
        "versus",
        "vertigem",
        "veto",
        "vice",
        "vicioso",
        "vítima",
        "vítima",
        "vilão",
        "vilão",
        "vingativo",
        "violação",
        "violência",
        "violento",
        "violentamente",
        "víbora",
        "virulência",
        "vírus",
        "visitação",
        "vixen",
        "volatilidade",
        "vulcão",
        "vômito",
        "Voodoo",
        "vulgar",
        "vulgaridade",
        "vulnerabilidade",
        "abutre",
        "waffle",
        "lamento",
        "esperar",
        "chafurdar",
        "NO TRANSLATION",
        "piora",
        "querendo",
        "guerra",
        "guardião",
        "louça",
        "guerra",
        "guerreiro",
        "advertir",
        "urdidura",
        "distorcido",
        "verruga",
        "desperdício",
        "desperdiçado",
        "desperdício",
        "desperdiçando",
        "aquoso",
        "vacilar",
        "enfraquecido",
        "fracamente",
        "fraqueza",
        "vestem",
        "cansadamente",
        "cansaço",
        "cansado",
        "ervas daninhas",
        "chorar",
        "esquisito",
        "estranho",
        "NO TRANSLATION",
        "moça",
        "whack",
        "capricho",
        "lamentar",
        "chicote",
        "torbellino",
        "Uísque",
        "prostituta",
        "perverso",
        "maldade",
        "selvagem",
        "gato selvagem",
        "incêndios",
        "intencional",
        "covarde",
        "mau",
        "estremecer",
        "bruxa",
        "feitiçaria",
        "retirar o",
        "murchar",
        "murchado",
        "ai",
        "lamenta",
        "lamentavelmente",
        "palavras",
        "Minhoca",
        "desgastado",
        "preocupado",
        "preocupação",
        "preocupante",
        "pior",
        "piora",
        "inútil",
        "ferida",
        "discussão",
        "ira",
        "causar",
        "destruir",
        "naufragado",
        "chave inglesa",
        "luta livre",
        "miserável",
        "miserável",
        "errado",
        "erro",
        "injusto",
        "erroneamente",
        "forjado",
        "wry",
        "xenofobia",
        "bocejar",
        "bocejando",
        "grito",
        "amarelos",
        "gritar",
        "fecho eclair",
    ]
)

_ambivalent = set(
    [
        "abundância",
        "armado",
        "bálsamo",
        "se vangloriar",
        "barulhento",
        "ratinho do livro",
        "buck",
        "celebridade",
        "Encantado",
        "evasão",
        "cumplicidade",
        "confessar",
        "destreza",
        "dependente",
        "diverso",
        "dominar",
        "sem fim",
        "reforçar",
        "erótico",
        "escapar",
        "sentindo-me",
        "flerte",
        "saudar",
        "hedonismo",
        "mais alto",
        "humilde",
        "imediatamente",
        "imobiliário",
        "renda",
        "infiltração",
        "influência",
        "intenso",
        "interminável",
        "intervenção",
        "laço",
        "liberal",
        "senhor",
        "materno",
        "parteira",
        "mãe",
        "caneca",
        "notoriedade",
        "onipotência",
        "explosão",
        "excepcional",
        "parada",
        "paráfrase",
        "petróleo",
        "apresentação",
        "pródigo",
        "citar",
        "delírio",
        "regressivo",
        "reativar",
        "permanece",
        "aposentadoria",
        "reviver",
        "revolução",
        "espantalho",
        "isolamento",
        "sensual",
        "espetáculo",
        "coluna vertebral",
        "esterlina",
        "suculentos",
        "superstição",
        "supremacia",
        "surround",
        "sinônimo",
        "tentador",
        "adolescentes",
        "tratar",
        "invicto",
        "desenfreado",
        "inesperado",
        "inimaginável",
        "desatar",
        "subida",
        "voto",
        "peso",
        "anseio",
    ]
)



from math import cos, sin, radians
import random
import matplotlib.patches as mpatches
import matplotlib.path as mpath
from matplotlib.collections import PatchCollection
import networkx as nx
from emoatlas.resources import _valences
import community.community_louvain as commlouv
import matplotlib.patheffects as path_effects
import matplotlib.pyplot as plt
from deep_translator import GoogleTranslator

language_codes = {
    "catalan": "ca",
    "chinese": "zh",
    "danish": "da",
    "dutch": "nl",
    "english": "en",
    "french": "fr",
    "german": "de",
    "greek": "el",
    "italian": "it",
    "japanese": "ja",
    "lithuanian": "lt",
    "macedonian": "mk",
    "norwegian": "no",
    "polish": "pl",
    "portoguese": "pt",
    "romanian": "ro",
    "russian": "ru",
    "spanish": "es",
}


def _rotate_point(point, angle):
    """
    Rotate a point counterclockwise by a given angle around a given origin.
    Required arguments:
    ----------
    *point*:
        A two-values tuple, (x, y), of the point to rotate

    *angle*:
        The angle the point is rotated. The angle should be given in radians.

    Returns:
    ----------
    *(qx, qy)*:
        A two-values tuple, the new coordinates of the rotated point.

    """
    ox, oy = 0, 0
    px, py = point
    angle = radians(angle)
    qx = ox + cos(angle) * (px - ox) - sin(angle) * (py - oy)
    qy = oy + sin(angle) * (px - ox) + cos(angle) * (py - oy)
    return (qx, qy)


def _noise(v, eps):
    return random.uniform(v - eps, v + eps)


def _initial_positions(n, eps):
    m = n - 1
    points = [(0, 0)] + [_rotate_point((0, 0.8), (360 / m) * i) for i in range(m)]
    points = [(_noise(x, eps), _noise(y, eps)) for x, y in points]

    return points


def _compute_link(posx, posy, centr1, centr2):

    # Middle point between the centroids of the clusters of x and y
    xx = _prop(centr1, centr2, 0.5)

    # Define Bezier curve
    Path = mpath.Path
    path_data = [(Path.MOVETO, posx), (Path.CURVE3, xx), (Path.CURVE3, posy)]

    # add the Path to ax
    codes, verts = zip(*path_data)
    path = mpath.Path(verts, codes)
    patch = mpatches.PathPatch(path)

    return patch


def _prop(a, b, t=0.5):

    midx = a[0] * t + b[0] * (1 - t)
    midy = a[1] * t + b[1] * (1 - t)

    return (midx, midy)


def _hex_to_rgb(value):
    value = value.lstrip("#")
    lv = len(value)
    lv = [int(value[i : i + lv // 3], 16) for i in range(0, lv, lv // 3)]
    lv = [l / 255 for l in lv] + [1]
    return lv


def _edge_color(w1, w2, _positive, _negative, _ambivalent, colz):
    if w1 in _positive and w2 in _positive:
        return colz["positive"]
    if w1 in _negative and w2 in _negative:
        return colz["negative"]

    if w1 in _negative and w2 in _positive:
        return "purple"
    if w1 in _positive and w2 in _negative:
        return "purple"

    if w1 in _positive or w2 in _positive:
        return colz["semipositive"]
    if w1 in _negative or w2 in _negative:
        return colz["seminegative"]

    return "lightgrey"


def draw_formamentis_force_layout(
    edgelist,
    highlight=[],
    language="english",
    thickness=1,
    ax=None,
    translated=False,
    alpha_syntactic=0.5,
    alpha_hypernyms=0.5,
    alpha_synonyms=0.5,
):
    """ """

    # Define color-blind palette
    colz = {
        "positive": (26 / 256, 133 / 256, 255 / 256),
        "negative": (255 / 256, 25 / 256, 25 / 256),  # (212/256, 17/256, 89/256),
        "synonyms": (34 / 256, 139 / 256, 34 / 256),
        "hypernyms": (255 / 256, 193 / 256, 7 / 256),
        "semipositive": (117 / 256, 152 / 256, 191 / 256),
        "seminegative": (200 / 256, 50 / 256, 50 / 256),
    }  # (196/256, 128/256, 153/256)}

    # Get positive or negative valences
    _positive, _negative, _ambivalent = _valences(language)

    # Prepare the patch effect for bicolor patches
    eff = [
        path_effects.PathPatchEffect(
            fc=(0.9, 0.9, 0.9), edgecolor=colz["negative"], linewidth=2
        ),
        path_effects.PathPatchEffect(
            edgecolor=colz["positive"],
            linewidth=2,
            facecolor=(0, 0, 0, 0),
            linestyle="--",
        ),
    ]

    if not ax:
        _, ax = plt.subplots(figsize=(9, 9))

    # Getting edgelist stripped of type
    if type(edgelist) == list:
        edge_type = ["syntactic"] * len(edgelist)
        edgelist = edgelist
    else:
        edges = []
        edge_type = []

        edges.extend(edgelist["syntactic"])
        edge_type.extend(["syntactic"] * len(edgelist["syntactic"]))

        try:
            edges.extend(edgelist["synonyms"])
            edge_type.extend(["synonyms"] * len(edgelist["synonyms"]))
        except:
            pass

        try:
            edges.extend(edgelist["hypernyms"])
            edge_type.extend(["hypernyms"] * len(edgelist["hypernyms"]))
        except:
            pass

        edgelist = edges

    G = nx.Graph(edgelist)

    # Clusters and centroids
    louv = commlouv.best_partition(G)
    comms = set(louv.values())
    try:
        eps = 2 / (len(comms) - 2)
    except:
        eps = 1

    # Positions
    centroids = _initial_positions(len(comms), eps)
    centroids = {c: cent for c, cent in zip(comms, centroids)}

    # Noise nodes position around their centroids
    pos = {}
    eps = eps / 3
    for node in G.nodes():
        pos[node] = (
            _noise(centroids[louv[node]][0], eps),
            _noise(centroids[louv[node]][1], eps),
        )
        # here one should avoid overlaps!

    # Just one quick iteration of spring_layout to optimize intra- and inter-cluster distances
    pos = nx.spring_layout(G, pos=pos, iterations=1, scale=4, k=1)

    # Draw EDGES :: Bezier curves

    patches = []
    colors = []
    alphas = []
    j = 0
    for x, y in edgelist:

        if edge_type[j] == "synonyms":
            color = colz["synonyms"]
            alpha = 0.2 * (alpha_synonyms * 2)
        elif edge_type[j] == "hypernyms":
            color = colz["hypernyms"]
            alpha = 0.2 * (alpha_hypernyms * 2)

        else:
            alpha = 0.2 * (alpha_syntactic * 2)
            color = _edge_color(x, y, _positive, _negative, _ambivalent, colz)

        if louv[x] != louv[y]:

            c1 = centroids[louv[x]]
            c2 = centroids[louv[y]]
            patches.append(_compute_link(pos[x], pos[y], c1, c2))
            colors.append(color)
            alphas.append(alpha)

        else:
            plt.plot(
                [pos[x][0], pos[y][0]],
                [pos[x][1], pos[y][1]],
                color=color,
                linewidth=thickness,
                alpha=alpha,
                zorder=-1,
            )

        j += 1

    # Darker alphas for this type of edges:
    alphas = [x * 1.5 for x in alphas]

    patches = PatchCollection(
        patches,
        facecolor="none",
        linewidth=thickness,
        edgecolor=colors,
        match_original=True,
        alpha=alphas,
        zorder=0,
    )
    ax.add_collection(patches)

    # Draw NODES

    degs = dict(G.degree())
    mindeg, maxdeg = min(degs.values()), max(degs.values())
    degs = {k: (v - mindeg) / (maxdeg - mindeg) for k, v in degs.items()}

    minfont = 10
    maxorder = 7

    for key, val in pos.items():

        fontsize = minfont + 5 * (degs[key] ** 3)
        zorder = int(degs[key] * 6)
        weight = "regular"

    if translated == True:
        for key, val in pos.items():
            fontsize = minfont + 5 * (degs[key] ** 3)
            zorder = int(degs[key] * 6)
            weight = "regular"

            if key in highlight:
                fontsize = 18
                zorder = maxorder + 1
                weight = "heavy"

            if key in _positive:
                # shadow!
                plt.annotate(
                    GoogleTranslator(source=language_codes[language], target="en")
                    .translate(key)
                    .lower(),
                    xy=(val[0] * 1.01, val[1] * 1.005),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=(0.7, 0.7, 0.7),
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.7, 0.7, 0.7),
                        ec=(0.7, 0.7, 0.7),
                        linewidth=4,
                    ),
                )

                plt.annotate(
                    GoogleTranslator(source=language_codes[language], target="en")
                    .translate(key)
                    .lower(),
                    xy=(val[0], val[1]),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=colz["positive"],
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.9, 0.9, 0.9),
                        ec=(0.9, 0.9, 0.9),
                        linewidth=4,
                    ),
                )

            elif key in _negative:
                # shadow!
                plt.annotate(
                    GoogleTranslator(source=language_codes[language], target="en")
                    .translate(key)
                    .lower(),
                    xy=(val[0] * 1.01, val[1] * 1.005),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=(0.7, 0.7, 0.7),
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.7, 0.7, 0.7),
                        ec=(0.7, 0.7, 0.7),
                        linewidth=4,
                    ),
                )

                plt.annotate(
                    GoogleTranslator(source=language_codes[language], target="en")
                    .translate(key)
                    .lower(),
                    xy=(val[0], val[1]),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=colz["negative"],
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.9, 0.9, 0.9),
                        ec=(0.9, 0.9, 0.9),
                        linewidth=4,
                    ),
                )

            elif key in _ambivalent:
                # shadow!
                plt.annotate(
                    GoogleTranslator(source=language_codes[language], target="en")
                    .translate(key)
                    .lower(),
                    xy=(val[0] * 1.01, val[1] * 1.005),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=(0.7, 0.7, 0.7),
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.7, 0.7, 0.7),
                        ec=(0.7, 0.7, 0.7),
                        linewidth=4,
                    ),
                )

                plt.annotate(
                    GoogleTranslator(source=language_codes[language], target="en")
                    .translate(key)
                    .lower(),
                    xy=(val[0], val[1]),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.9, 0.9, 0.9),
                        ec=(119 / 255, 221 / 255, 118 / 255, 0.7),
                        path_effects=eff,
                        linewidth=3,
                    ),
                )

            else:
                plt.annotate(
                    GoogleTranslator(source=language_codes[language], target="en")
                    .translate(key)
                    .lower(),
                    xy=(val[0], val[1]),
                    zorder=zorder,
                    fontsize=fontsize,
                    weight=weight,
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.85, 0.85, 0.85),
                        ec=(0.8, 0.8, 0.8),
                        linewidth=1,
                    ),
                )
    else:  # translated=false
        for key, val in pos.items():
            fontsize = minfont + 5 * (degs[key] ** 3)
            zorder = int(degs[key] * 6)
            weight = "regular"

            if key in highlight:
                fontsize = 18
                zorder = maxorder + 1
                weight = "heavy"

            if key in _positive:
                # shadow!
                plt.annotate(
                    key,
                    xy=(val[0] * 1.01, val[1] * 1.005),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=(0.7, 0.7, 0.7),
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.7, 0.7, 0.7),
                        ec=(0.7, 0.7, 0.7),
                        linewidth=4,
                    ),
                )

                plt.annotate(
                    key,
                    xy=(val[0], val[1]),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=colz["positive"],
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.9, 0.9, 0.9),
                        ec=(0.9, 0.9, 0.9),
                        linewidth=4,
                    ),
                )

            elif key in _negative:
                # shadow!
                plt.annotate(
                    key,
                    xy=(val[0] * 1.01, val[1] * 1.005),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=(0.7, 0.7, 0.7),
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.7, 0.7, 0.7),
                        ec=(0.7, 0.7, 0.7),
                        linewidth=4,
                    ),
                )

                plt.annotate(
                    key,
                    xy=(val[0], val[1]),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=colz["negative"],
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.9, 0.9, 0.9),
                        ec=(0.9, 0.9, 0.9),
                        linewidth=4,
                    ),
                )

            elif key in _ambivalent:
                # shadow!
                plt.annotate(
                    key,
                    xy=(val[0] * 1.01, val[1] * 1.005),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    color=(0.7, 0.7, 0.7),
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.7, 0.7, 0.7),
                        ec=(0.7, 0.7, 0.7),
                        linewidth=4,
                    ),
                )

                plt.annotate(
                    key,
                    xy=(val[0], val[1]),
                    zorder=maxorder,
                    fontsize=fontsize,
                    weight=weight,
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.9, 0.9, 0.9),
                        ec=(119 / 255, 221 / 255, 118 / 255, 0.7),
                        path_effects=eff,
                        linewidth=3,
                    ),
                )

            else:
                plt.annotate(
                    key,
                    xy=(val[0], val[1]),
                    zorder=zorder,
                    fontsize=fontsize,
                    weight=weight,
                    bbox=dict(
                        boxstyle="round",
                        fc=(0.85, 0.85, 0.85),
                        ec=(0.8, 0.8, 0.8),
                        linewidth=1,
                    ),
                )

    ax.axis("off")

    return ax
